import os, string

INCFLAGS = []
CFLAGS   = []
LDFLAGS  = []
LIBS     = []
if 'INCFLAGS' in os.environ:
   INCFLAGS = os.environ['INCFLAGS'].split()

if 'CFLAGS' in os.environ:
   CFLAGS  = os.environ['CFLAGS'].split()

if 'LDFLAGS' in os.environ:
   LDFLAGS  = os.environ['LDFLAGS'].split('-L')

if 'LIBS' in os.environ:
   LIBS     = os.environ['LIBS'].split()



import CdiObj

ifile = "../testdata/mulval.grb"

cdi = CdiObj.Cdi(ifile)

print 'Stream: ',cdi.streamID,' vlistID:',cdi.vlistID,' nvars:{d}', cdi.nvars

print '#========== TAXES ====================================#'
for k in range(cdi.taxes.size()):
  print  k,": ", cdi.taxes[k].ntsteps

print '#========== GRIDS ====================================#'
for k in range(cdi.grids.size()):
  print k,": ", cdi.grids[k].size,' ', cdi.grids[k].xname,' ', cdi.grids[k].yname,' ', cdi.grids[k].ylongname 

print "#========== ZAXES ====================================#"
for k in range(cdi.zaxes.size()):
  print k,": ", cdi.zaxes[k].size,' ', cdi.zaxes[k].name,' ', cdi.zaxes[k].units

print "#========== VARIABLES ================================#"
for k in range(cdi.variables.size()):
  v = cdi.variables[k]
  print v.name," ",v.size, " ", v.missval

print "#========== VARIABLEcdi.NAMES =================================#"
for k in range(cdi.variables.size()):
  print cdi.variables[k].longname,' ',cdi.variables[k].units

print "#========== VAR by index ======================================#"
var = cdi.variables[1]
var.getValues()
val = var.values
i=0; print 'val[',i,'] = ',val[i]
i=1; print 'val[',i,'] = ',val[i]
i=2; print 'val[',i,'] = ',val[i]
i=3; print 'val[',i,'] = ',val[i]
i=4; print 'val[',i,'] = ',val[i]
i=5; print 'val[',i,'] = ',val[i]
print "#========= Var by name ===============================#"
name ="tsurf"
newvar = cdi.var[name]
print "name ",name," var.name: ", newvar.name, " var.grids.xsize: " , newvar.grid.xsize
print "#========= Var by code ===============================#"
code = 169
newvar = cdi.varByCode[code]
newvar.sinfo()



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 1.3.36
#
# Don't modify this file, modify the SWIG interface instead.
# This file is compatible with both classic and new-style classes.

import _CdiLib
import new
new_instancemethod = new.instancemethod
try:
    _swig_property = property
except NameError:
    pass # Python < 2.2 doesn't have 'property'.
def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "thisown"): return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'PySwigObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    if (name == "thisown"): return self.this.own()
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

def _swig_repr(self):
    try: strthis = "proxy of " + self.this.__repr__()
    except: strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


CDI_UNDEFID = _CdiLib.CDI_UNDEFID
CDI_GLOBAL = _CdiLib.CDI_GLOBAL
CDI_BIGENDIAN = _CdiLib.CDI_BIGENDIAN
CDI_LITTLEENDIAN = _CdiLib.CDI_LITTLEENDIAN
CDI_NOERR = _CdiLib.CDI_NOERR
CDI_ESYSTEM = _CdiLib.CDI_ESYSTEM
CDI_EINVAL = _CdiLib.CDI_EINVAL
CDI_EUFTYPE = _CdiLib.CDI_EUFTYPE
CDI_ELIBNAVAIL = _CdiLib.CDI_ELIBNAVAIL
CDI_EUFSTRUCT = _CdiLib.CDI_EUFSTRUCT
CDI_EUNC4 = _CdiLib.CDI_EUNC4
FILETYPE_GRB = _CdiLib.FILETYPE_GRB
FILETYPE_GRB2 = _CdiLib.FILETYPE_GRB2
FILETYPE_NC = _CdiLib.FILETYPE_NC
FILETYPE_NC2 = _CdiLib.FILETYPE_NC2
FILETYPE_NC4 = _CdiLib.FILETYPE_NC4
FILETYPE_SRV = _CdiLib.FILETYPE_SRV
FILETYPE_EXT = _CdiLib.FILETYPE_EXT
FILETYPE_IEG = _CdiLib.FILETYPE_IEG
COMPRESS_NONE = _CdiLib.COMPRESS_NONE
COMPRESS_SZIP = _CdiLib.COMPRESS_SZIP
COMPRESS_GZIP = _CdiLib.COMPRESS_GZIP
COMPRESS_BZIP2 = _CdiLib.COMPRESS_BZIP2
COMPRESS_ZIP = _CdiLib.COMPRESS_ZIP
DATATYPE_PACK = _CdiLib.DATATYPE_PACK
DATATYPE_PACK1 = _CdiLib.DATATYPE_PACK1
DATATYPE_PACK2 = _CdiLib.DATATYPE_PACK2
DATATYPE_PACK3 = _CdiLib.DATATYPE_PACK3
DATATYPE_PACK4 = _CdiLib.DATATYPE_PACK4
DATATYPE_PACK5 = _CdiLib.DATATYPE_PACK5
DATATYPE_PACK6 = _CdiLib.DATATYPE_PACK6
DATATYPE_PACK7 = _CdiLib.DATATYPE_PACK7
DATATYPE_PACK8 = _CdiLib.DATATYPE_PACK8
DATATYPE_PACK9 = _CdiLib.DATATYPE_PACK9
DATATYPE_PACK10 = _CdiLib.DATATYPE_PACK10
DATATYPE_PACK11 = _CdiLib.DATATYPE_PACK11
DATATYPE_PACK12 = _CdiLib.DATATYPE_PACK12
DATATYPE_PACK13 = _CdiLib.DATATYPE_PACK13
DATATYPE_PACK14 = _CdiLib.DATATYPE_PACK14
DATATYPE_PACK15 = _CdiLib.DATATYPE_PACK15
DATATYPE_PACK16 = _CdiLib.DATATYPE_PACK16
DATATYPE_PACK17 = _CdiLib.DATATYPE_PACK17
DATATYPE_PACK18 = _CdiLib.DATATYPE_PACK18
DATATYPE_PACK19 = _CdiLib.DATATYPE_PACK19
DATATYPE_PACK20 = _CdiLib.DATATYPE_PACK20
DATATYPE_PACK21 = _CdiLib.DATATYPE_PACK21
DATATYPE_PACK22 = _CdiLib.DATATYPE_PACK22
DATATYPE_PACK23 = _CdiLib.DATATYPE_PACK23
DATATYPE_PACK24 = _CdiLib.DATATYPE_PACK24
DATATYPE_PACK25 = _CdiLib.DATATYPE_PACK25
DATATYPE_PACK26 = _CdiLib.DATATYPE_PACK26
DATATYPE_PACK27 = _CdiLib.DATATYPE_PACK27
DATATYPE_PACK28 = _CdiLib.DATATYPE_PACK28
DATATYPE_PACK29 = _CdiLib.DATATYPE_PACK29
DATATYPE_PACK30 = _CdiLib.DATATYPE_PACK30
DATATYPE_PACK31 = _CdiLib.DATATYPE_PACK31
DATATYPE_PACK32 = _CdiLib.DATATYPE_PACK32
DATATYPE_FLT32 = _CdiLib.DATATYPE_FLT32
DATATYPE_FLT64 = _CdiLib.DATATYPE_FLT64
DATATYPE_INT8 = _CdiLib.DATATYPE_INT8
DATATYPE_INT16 = _CdiLib.DATATYPE_INT16
DATATYPE_INT32 = _CdiLib.DATATYPE_INT32
DATATYPE_UINT8 = _CdiLib.DATATYPE_UINT8
DATATYPE_UINT16 = _CdiLib.DATATYPE_UINT16
DATATYPE_UINT32 = _CdiLib.DATATYPE_UINT32
DATATYPE_INT = _CdiLib.DATATYPE_INT
DATATYPE_FLT = _CdiLib.DATATYPE_FLT
DATATYPE_TXT = _CdiLib.DATATYPE_TXT
GRID_GENERIC = _CdiLib.GRID_GENERIC
GRID_GAUSSIAN = _CdiLib.GRID_GAUSSIAN
GRID_GAUSSIAN_REDUCED = _CdiLib.GRID_GAUSSIAN_REDUCED
GRID_LONLAT = _CdiLib.GRID_LONLAT
GRID_SPECTRAL = _CdiLib.GRID_SPECTRAL
GRID_FOURIER = _CdiLib.GRID_FOURIER
GRID_GME = _CdiLib.GRID_GME
GRID_TRAJECTORY = _CdiLib.GRID_TRAJECTORY
GRID_UNSTRUCTURED = _CdiLib.GRID_UNSTRUCTURED
GRID_CURVILINEAR = _CdiLib.GRID_CURVILINEAR
GRID_LCC = _CdiLib.GRID_LCC
GRID_LCC2 = _CdiLib.GRID_LCC2
GRID_LAEA = _CdiLib.GRID_LAEA
GRID_SINUSOIDAL = _CdiLib.GRID_SINUSOIDAL
ZAXIS_SURFACE = _CdiLib.ZAXIS_SURFACE
ZAXIS_GENERIC = _CdiLib.ZAXIS_GENERIC
ZAXIS_HYBRID = _CdiLib.ZAXIS_HYBRID
ZAXIS_HYBRID_HALF = _CdiLib.ZAXIS_HYBRID_HALF
ZAXIS_PRESSURE = _CdiLib.ZAXIS_PRESSURE
ZAXIS_HEIGHT = _CdiLib.ZAXIS_HEIGHT
ZAXIS_DEPTH_BELOW_SEA = _CdiLib.ZAXIS_DEPTH_BELOW_SEA
ZAXIS_DEPTH_BELOW_LAND = _CdiLib.ZAXIS_DEPTH_BELOW_LAND
ZAXIS_ISENTROPIC = _CdiLib.ZAXIS_ISENTROPIC
ZAXIS_TRAJECTORY = _CdiLib.ZAXIS_TRAJECTORY
ZAXIS_ALTITUDE = _CdiLib.ZAXIS_ALTITUDE
ZAXIS_SIGMA = _CdiLib.ZAXIS_SIGMA
ZAXIS_MEANSEA = _CdiLib.ZAXIS_MEANSEA
TAXIS_ABSOLUTE = _CdiLib.TAXIS_ABSOLUTE
TAXIS_RELATIVE = _CdiLib.TAXIS_RELATIVE
TIME_CONSTANT = _CdiLib.TIME_CONSTANT
TIME_VARIABLE = _CdiLib.TIME_VARIABLE
TUNIT_SECOND = _CdiLib.TUNIT_SECOND
TUNIT_MINUTE = _CdiLib.TUNIT_MINUTE
TUNIT_HOUR = _CdiLib.TUNIT_HOUR
TUNIT_DAY = _CdiLib.TUNIT_DAY
TUNIT_MONTH = _CdiLib.TUNIT_MONTH
TUNIT_YEAR = _CdiLib.TUNIT_YEAR
TUNIT_QUARTER = _CdiLib.TUNIT_QUARTER
CALENDAR_STANDARD = _CdiLib.CALENDAR_STANDARD
CALENDAR_PROLEPTIC = _CdiLib.CALENDAR_PROLEPTIC
CALENDAR_360DAYS = _CdiLib.CALENDAR_360DAYS
CALENDAR_365DAYS = _CdiLib.CALENDAR_365DAYS
CALENDAR_366DAYS = _CdiLib.CALENDAR_366DAYS
CALENDAR_NONE = _CdiLib.CALENDAR_NONE
cdiStringError = _CdiLib.cdiStringError
cdiDebug = _CdiLib.cdiDebug
cdiLibraryVersion = _CdiLib.cdiLibraryVersion
cdiPrintVersion = _CdiLib.cdiPrintVersion
cdiDefMissval = _CdiLib.cdiDefMissval
cdiInqMissval = _CdiLib.cdiInqMissval
cdiDefGlobal = _CdiLib.cdiDefGlobal
streamOpenRead = _CdiLib.streamOpenRead
streamOpenWrite = _CdiLib.streamOpenWrite
streamOpenAppend = _CdiLib.streamOpenAppend
streamClose = _CdiLib.streamClose
streamSync = _CdiLib.streamSync
streamDefVlist = _CdiLib.streamDefVlist
streamInqVlist = _CdiLib.streamInqVlist
streamInqFiletype = _CdiLib.streamInqFiletype
streamDefByteorder = _CdiLib.streamDefByteorder
streamInqByteorder = _CdiLib.streamInqByteorder
streamDefZtype = _CdiLib.streamDefZtype
streamDefZlevel = _CdiLib.streamDefZlevel
streamInqZtype = _CdiLib.streamInqZtype
streamInqZlevel = _CdiLib.streamInqZlevel
streamDefTimestep = _CdiLib.streamDefTimestep
streamInqTimestep = _CdiLib.streamInqTimestep
streamFilename = _CdiLib.streamFilename
streamFilesuffix = _CdiLib.streamFilesuffix
streamNtsteps = _CdiLib.streamNtsteps
streamNvals = _CdiLib.streamNvals
streamReadVar = _CdiLib.streamReadVar
streamWriteVar = _CdiLib.streamWriteVar
streamReadVarSlice = _CdiLib.streamReadVarSlice
streamWriteVarSlice = _CdiLib.streamWriteVarSlice
streamInqRecord = _CdiLib.streamInqRecord
streamDefRecord = _CdiLib.streamDefRecord
streamReadRecord = _CdiLib.streamReadRecord
streamWriteRecord = _CdiLib.streamWriteRecord
streamCopyRecord = _CdiLib.streamCopyRecord
streamInqGinfo = _CdiLib.streamInqGinfo
vlistCreate = _CdiLib.vlistCreate
vlistDestroy = _CdiLib.vlistDestroy
vlistDuplicate = _CdiLib.vlistDuplicate
vlistCopy = _CdiLib.vlistCopy
vlistCopyFlag = _CdiLib.vlistCopyFlag
vlistClearFlag = _CdiLib.vlistClearFlag
vlistCat = _CdiLib.vlistCat
vlistMerge = _CdiLib.vlistMerge
vlistPrint = _CdiLib.vlistPrint
vlistNvars = _CdiLib.vlistNvars
vlistNgrids = _CdiLib.vlistNgrids
vlistNzaxis = _CdiLib.vlistNzaxis
vlistDefNtsteps = _CdiLib.vlistDefNtsteps
vlistNtsteps = _CdiLib.vlistNtsteps
vlistGridsizeMax = _CdiLib.vlistGridsizeMax
vlistGrid = _CdiLib.vlistGrid
vlistGridIndex = _CdiLib.vlistGridIndex
vlistChangeGridIndex = _CdiLib.vlistChangeGridIndex
vlistChangeGrid = _CdiLib.vlistChangeGrid
vlistZaxis = _CdiLib.vlistZaxis
vlistZaxisIndex = _CdiLib.vlistZaxisIndex
vlistChangeZaxisIndex = _CdiLib.vlistChangeZaxisIndex
vlistChangeZaxis = _CdiLib.vlistChangeZaxis
vlistNrecs = _CdiLib.vlistNrecs
vlistDefTaxis = _CdiLib.vlistDefTaxis
vlistInqTaxis = _CdiLib.vlistInqTaxis
vlistDefTable = _CdiLib.vlistDefTable
vlistInqTable = _CdiLib.vlistInqTable
vlistDefInstitut = _CdiLib.vlistDefInstitut
vlistInqInstitut = _CdiLib.vlistInqInstitut
vlistDefModel = _CdiLib.vlistDefModel
vlistInqModel = _CdiLib.vlistInqModel
vlistDefVar = _CdiLib.vlistDefVar
vlistChangeVarGrid = _CdiLib.vlistChangeVarGrid
vlistChangeVarZaxis = _CdiLib.vlistChangeVarZaxis
vlistInqVar = _CdiLib.vlistInqVar
vlistInqVarGrid = _CdiLib.vlistInqVarGrid
vlistInqVarZaxis = _CdiLib.vlistInqVarZaxis
vlistInqVarTime = _CdiLib.vlistInqVarTime
vlistDefVarZtype = _CdiLib.vlistDefVarZtype
vlistInqVarZtype = _CdiLib.vlistInqVarZtype
vlistDefVarZlevel = _CdiLib.vlistDefVarZlevel
vlistInqVarZlevel = _CdiLib.vlistInqVarZlevel
vlistDefVarCode = _CdiLib.vlistDefVarCode
vlistInqVarCode = _CdiLib.vlistInqVarCode
vlistDefVarDatatype = _CdiLib.vlistDefVarDatatype
vlistInqVarDatatype = _CdiLib.vlistInqVarDatatype
vlistDefVarInstitut = _CdiLib.vlistDefVarInstitut
vlistInqVarInstitut = _CdiLib.vlistInqVarInstitut
vlistDefVarModel = _CdiLib.vlistDefVarModel
vlistInqVarModel = _CdiLib.vlistInqVarModel
vlistDefVarTable = _CdiLib.vlistDefVarTable
vlistInqVarTable = _CdiLib.vlistInqVarTable
vlistDefVarName = _CdiLib.vlistDefVarName
vlistInqVarName = _CdiLib.vlistInqVarName
vlistDefVarLongname = _CdiLib.vlistDefVarLongname
vlistDefVarStdname = _CdiLib.vlistDefVarStdname
vlistInqVarLongname = _CdiLib.vlistInqVarLongname
vlistInqVarStdname = _CdiLib.vlistInqVarStdname
vlistDefVarUnits = _CdiLib.vlistDefVarUnits
vlistInqVarUnits = _CdiLib.vlistInqVarUnits
vlistDefVarMissval = _CdiLib.vlistDefVarMissval
vlistInqVarMissval = _CdiLib.vlistInqVarMissval
vlistDefVarScalefactor = _CdiLib.vlistDefVarScalefactor
vlistInqVarScalefactor = _CdiLib.vlistInqVarScalefactor
vlistDefVarAddoffset = _CdiLib.vlistDefVarAddoffset
vlistInqVarAddoffset = _CdiLib.vlistInqVarAddoffset
vlistDefVarTimave = _CdiLib.vlistDefVarTimave
vlistInqVarTimave = _CdiLib.vlistInqVarTimave
vlistDefVarTimaccu = _CdiLib.vlistDefVarTimaccu
vlistInqVarTimaccu = _CdiLib.vlistInqVarTimaccu
vlistInqVarSize = _CdiLib.vlistInqVarSize
vlistInqVarID = _CdiLib.vlistInqVarID
vlistDefIndex = _CdiLib.vlistDefIndex
vlistInqIndex = _CdiLib.vlistInqIndex
vlistDefFlag = _CdiLib.vlistDefFlag
vlistInqFlag = _CdiLib.vlistInqFlag
vlistFindVar = _CdiLib.vlistFindVar
vlistFindLevel = _CdiLib.vlistFindLevel
vlistMergedVar = _CdiLib.vlistMergedVar
vlistMergedLevel = _CdiLib.vlistMergedLevel
vlistInqNatts = _CdiLib.vlistInqNatts
vlistInqAtt = _CdiLib.vlistInqAtt
vlistDelAtt = _CdiLib.vlistDelAtt
vlistDefAttInt = _CdiLib.vlistDefAttInt
vlistDefAttFlt = _CdiLib.vlistDefAttFlt
vlistDefAttTxt = _CdiLib.vlistDefAttTxt
vlistInqAttInt = _CdiLib.vlistInqAttInt
vlistInqAttFlt = _CdiLib.vlistInqAttFlt
vlistInqAttTxt = _CdiLib.vlistInqAttTxt
gridName = _CdiLib.gridName
gridNamePtr = _CdiLib.gridNamePtr
gridCompress = _CdiLib.gridCompress
gridDefMask = _CdiLib.gridDefMask
gridInqMask = _CdiLib.gridInqMask
gridPrint = _CdiLib.gridPrint
gridSize = _CdiLib.gridSize
gridCreate = _CdiLib.gridCreate
gridDestroy = _CdiLib.gridDestroy
gridDuplicate = _CdiLib.gridDuplicate
gridInqType = _CdiLib.gridInqType
gridInqSize = _CdiLib.gridInqSize
gridDefXsize = _CdiLib.gridDefXsize
gridInqXsize = _CdiLib.gridInqXsize
gridDefYsize = _CdiLib.gridDefYsize
gridInqYsize = _CdiLib.gridInqYsize
gridDefXvals = _CdiLib.gridDefXvals
gridInqXvals = _CdiLib.gridInqXvals
gridDefYvals = _CdiLib.gridDefYvals
gridInqYvals = _CdiLib.gridInqYvals
gridDefXname = _CdiLib.gridDefXname
gridDefXlongname = _CdiLib.gridDefXlongname
gridDefXunits = _CdiLib.gridDefXunits
gridDefYname = _CdiLib.gridDefYname
gridDefYlongname = _CdiLib.gridDefYlongname
gridDefYunits = _CdiLib.gridDefYunits
gridInqXname = _CdiLib.gridInqXname
gridInqXlongname = _CdiLib.gridInqXlongname
gridInqXstdname = _CdiLib.gridInqXstdname
gridInqXunits = _CdiLib.gridInqXunits
gridInqYname = _CdiLib.gridInqYname
gridInqYlongname = _CdiLib.gridInqYlongname
gridInqYstdname = _CdiLib.gridInqYstdname
gridInqYunits = _CdiLib.gridInqYunits
gridDefPrec = _CdiLib.gridDefPrec
gridInqPrec = _CdiLib.gridInqPrec
gridInqXval = _CdiLib.gridInqXval
gridInqYval = _CdiLib.gridInqYval
gridInqXinc = _CdiLib.gridInqXinc
gridInqYinc = _CdiLib.gridInqYinc
gridIsCircular = _CdiLib.gridIsCircular
gridIsRotated = _CdiLib.gridIsRotated
gridInqXpole = _CdiLib.gridInqXpole
gridDefXpole = _CdiLib.gridDefXpole
gridInqYpole = _CdiLib.gridInqYpole
gridDefYpole = _CdiLib.gridDefYpole
gridInqAngle = _CdiLib.gridInqAngle
gridDefAngle = _CdiLib.gridDefAngle
gridDefTrunc = _CdiLib.gridDefTrunc
gridInqTrunc = _CdiLib.gridInqTrunc
gridInqGMEnd = _CdiLib.gridInqGMEnd
gridDefGMEnd = _CdiLib.gridDefGMEnd
gridInqGMEni = _CdiLib.gridInqGMEni
gridDefGMEni = _CdiLib.gridDefGMEni
gridInqGMEni2 = _CdiLib.gridInqGMEni2
gridDefGMEni2 = _CdiLib.gridDefGMEni2
gridInqGMEni3 = _CdiLib.gridInqGMEni3
gridDefGMEni3 = _CdiLib.gridDefGMEni3
gridDefLCC = _CdiLib.gridDefLCC
gridInqLCC = _CdiLib.gridInqLCC
gridDefLcc2 = _CdiLib.gridDefLcc2
gridInqLcc2 = _CdiLib.gridInqLcc2
gridDefLaea = _CdiLib.gridDefLaea
gridInqLaea = _CdiLib.gridInqLaea
gridDefArea = _CdiLib.gridDefArea
gridInqArea = _CdiLib.gridInqArea
gridHasArea = _CdiLib.gridHasArea
gridDefNvertex = _CdiLib.gridDefNvertex
gridInqNvertex = _CdiLib.gridInqNvertex
gridDefXbounds = _CdiLib.gridDefXbounds
gridInqXbounds = _CdiLib.gridInqXbounds
gridDefYbounds = _CdiLib.gridDefYbounds
gridInqYbounds = _CdiLib.gridInqYbounds
gridDefRowlon = _CdiLib.gridDefRowlon
gridInqRowlon = _CdiLib.gridInqRowlon
gridChangeType = _CdiLib.gridChangeType
zaxisName = _CdiLib.zaxisName
zaxisCreate = _CdiLib.zaxisCreate
zaxisDestroy = _CdiLib.zaxisDestroy
zaxisInqType = _CdiLib.zaxisInqType
zaxisInqSize = _CdiLib.zaxisInqSize
zaxisDuplicate = _CdiLib.zaxisDuplicate
zaxisResize = _CdiLib.zaxisResize
zaxisPrint = _CdiLib.zaxisPrint
zaxisSize = _CdiLib.zaxisSize
zaxisDefLevels = _CdiLib.zaxisDefLevels
zaxisInqLevels = _CdiLib.zaxisInqLevels
zaxisDefLevel = _CdiLib.zaxisDefLevel
zaxisInqLevel = _CdiLib.zaxisInqLevel
zaxisDefName = _CdiLib.zaxisDefName
zaxisDefLongname = _CdiLib.zaxisDefLongname
zaxisDefUnits = _CdiLib.zaxisDefUnits
zaxisInqName = _CdiLib.zaxisInqName
zaxisInqLongname = _CdiLib.zaxisInqLongname
zaxisInqUnits = _CdiLib.zaxisInqUnits
zaxisDefPrec = _CdiLib.zaxisDefPrec
zaxisInqPrec = _CdiLib.zaxisInqPrec
zaxisDefLtype = _CdiLib.zaxisDefLtype
zaxisInqLtype = _CdiLib.zaxisInqLtype
zaxisInqLevelsPtr = _CdiLib.zaxisInqLevelsPtr
zaxisDefVct = _CdiLib.zaxisDefVct
zaxisInqVctSize = _CdiLib.zaxisInqVctSize
zaxisInqVctPtr = _CdiLib.zaxisInqVctPtr
zaxisInqLbounds = _CdiLib.zaxisInqLbounds
zaxisInqUbounds = _CdiLib.zaxisInqUbounds
zaxisInqWeights = _CdiLib.zaxisInqWeights
zaxisInqLbound = _CdiLib.zaxisInqLbound
zaxisInqUbound = _CdiLib.zaxisInqUbound
zaxisDefLbounds = _CdiLib.zaxisDefLbounds
zaxisDefUbounds = _CdiLib.zaxisDefUbounds
zaxisDefWeights = _CdiLib.zaxisDefWeights
zaxisChangeType = _CdiLib.zaxisChangeType
taxisCreate = _CdiLib.taxisCreate
taxisDestroy = _CdiLib.taxisDestroy
taxisDuplicate = _CdiLib.taxisDuplicate
taxisCopyTimestep = _CdiLib.taxisCopyTimestep
taxisDefType = _CdiLib.taxisDefType
taxisDefVdate = _CdiLib.taxisDefVdate
taxisDefVtime = _CdiLib.taxisDefVtime
taxisDefRdate = _CdiLib.taxisDefRdate
taxisDefRtime = _CdiLib.taxisDefRtime
taxisHasBounds = _CdiLib.taxisHasBounds
taxisDefVdateBounds = _CdiLib.taxisDefVdateBounds
taxisDefVtimeBounds = _CdiLib.taxisDefVtimeBounds
taxisInqVdateBounds = _CdiLib.taxisInqVdateBounds
taxisInqVtimeBounds = _CdiLib.taxisInqVtimeBounds
taxisDefCalendar = _CdiLib.taxisDefCalendar
taxisDefTunit = _CdiLib.taxisDefTunit
taxisDefNumavg = _CdiLib.taxisDefNumavg
taxisInqType = _CdiLib.taxisInqType
taxisInqVdate = _CdiLib.taxisInqVdate
taxisInqVtime = _CdiLib.taxisInqVtime
taxisInqRdate = _CdiLib.taxisInqRdate
taxisInqRtime = _CdiLib.taxisInqRtime
taxisInqCalendar = _CdiLib.taxisInqCalendar
taxisInqTunit = _CdiLib.taxisInqTunit
taxisInqNumavg = _CdiLib.taxisInqNumavg
tunitNamePtr = _CdiLib.tunitNamePtr
institutDef = _CdiLib.institutDef
institutInq = _CdiLib.institutInq
institutInqNumber = _CdiLib.institutInqNumber
institutInqCenter = _CdiLib.institutInqCenter
institutInqSubcenter = _CdiLib.institutInqSubcenter
institutInqNamePtr = _CdiLib.institutInqNamePtr
institutInqLongnamePtr = _CdiLib.institutInqLongnamePtr
modelDef = _CdiLib.modelDef
modelInq = _CdiLib.modelInq
modelInqInstitut = _CdiLib.modelInqInstitut
modelInqGribID = _CdiLib.modelInqGribID
modelInqNamePtr = _CdiLib.modelInqNamePtr
tableWriteC = _CdiLib.tableWriteC
tableWrite = _CdiLib.tableWrite
tableRead = _CdiLib.tableRead
tableDef = _CdiLib.tableDef
tableInqNamePtr = _CdiLib.tableInqNamePtr
tableDefEntry = _CdiLib.tableDefEntry
tableInq = _CdiLib.tableInq
tableInqNumber = _CdiLib.tableInqNumber
tableInqNum = _CdiLib.tableInqNum
tableInqModel = _CdiLib.tableInqModel
tableInqPar = _CdiLib.tableInqPar
tableInqParCode = _CdiLib.tableInqParCode
tableInqParName = _CdiLib.tableInqParName
tableInqParLongname = _CdiLib.tableInqParLongname
tableInqParUnits = _CdiLib.tableInqParUnits
tableInqParNamePtr = _CdiLib.tableInqParNamePtr
tableInqParLongnamePtr = _CdiLib.tableInqParLongnamePtr
tableInqParUnitsPtr = _CdiLib.tableInqParUnitsPtr
streamDefHistory = _CdiLib.streamDefHistory
streamInqHistorySize = _CdiLib.streamInqHistorySize
streamInqHistoryString = _CdiLib.streamInqHistoryString





import os,re,subprocess,tempfile,random,string

# Copyright (C) 2011-2012 Ralf Mueller, ralf.mueller@zmaw.de
# See COPYING file for copying and redistribution conditions.
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

def auto_doc(tool, cdo_self):
    """Generate the __doc__ string of the decorated function by calling the cdo help command"""
    def desc(func):
        func.__doc__ = cdo_self.call([cdo_self.CDO, '-h', tool]).get('stdout')
        return func
    return desc

class CDOException(Exception):

    def __init__(self, stdout, stderr, returncode):
        super(CDOException, self).__init__()
        self.stdout     = stdout
        self.stderr     = stderr
        self.returncode = returncode
        self.msg        = '(returncode:%s) %s' % (returncode, stderr)

    def __str__(self):
        return self.msg

class Cdo(object):

  def __init__(self,returnCdf=False,returnNoneOnError=False,forceOutput=True,cdfMod='scipy',debug=False):
    # Since cdo-1.5.4 undocumented operators are given with the -h option. For
    # earlier version, they have to be provided manually
    self.undocumentedOperators = ['anomaly','beta','boxavg','change_e5lsm','change_e5mask',
        'change_e5slm','chisquare','chvar','cloudlayer','cmd','com','command','complextorect',
        'covar0','covar0r','daycount','daylogs','del29feb','delday','delete','deltap','deltap_fl',
        'delvar','diffv','divcoslat','dumplogo','dumplogs','duplicate','eca_r1mm','enlargegrid',
        'ensrkhistspace','ensrkhisttime','eof3d','eof3dspatial','eof3dtime','export_e5ml',
        'export_e5res','fc2gp','fc2sp','fillmiss','fisher','fldcovar','fldrms','fourier','fpressure',
        'gather','gengrid','geopotheight','ggstat','ggstats','globavg','gp2fc','gradsdes',
        'gridverify','harmonic','hourcount','hpressure','ifs2icon','import_e5ml','import_e5res',
        'import_obs','imtocomplex','infos','infov','interpolate','intgrid','intgridbil',
        'intgridtraj','intpoint','isosurface','lmavg','lmean','lmmean','lmstd','log','lsmean',
        'meandiff2test','mergegrid','mod','moncount','monlogs','mrotuv','mrotuvb','mulcoslat','ncode',
        'ncopy','nmltest','normal','nvar','outputbounds','outputboundscpt','outputcenter',
        'outputcenter2','outputcentercpt','outputkey','outputtri','outputvector','outputvrml',
        'pardup','parmul','pinfo','pinfov','pressure_fl','pressure_hl','read_e5ml','remapcon1',
        'remapdis1','retocomplex','scalllogo','scatter','seascount','select','selgridname',
        'seloperator','selvar','selzaxisname','setrcaname','setvar','showvar','sinfov','smemlogo',
        'snamelogo','sort','sortcode','sortlevel','sortname','sorttaxis','sorttimestamp','sortvar',
        'sp2fc','specinfo','spectrum','sperclogo','splitvar','stimelogo','studentt','template1',
        'template2','test','test2','testdata','thinout','timcount','timcovar','tinfo','transxy','trms',
        'tstepcount','vardes','vardup','varmul','varquot2test','varrms','vertwind','write_e5ml',
        'writegrid','writerandom','yearcount']

    if os.environ.has_key('CDO'):
      self.CDO = os.environ['CDO']
    else:
      self.CDO = 'cdo'

    self.operators              = self.getOperators()
    self.returnCdf              = returnCdf
    self.returnNoneOnError      = returnNoneOnError
    self.tempfile               = MyTempfile()
    self.forceOutput            = forceOutput
    self.cdfMod                 = cdfMod
    self.debug                  = debug
    self.outputOperatorsPattern = '(diff|info|output|griddes|zaxisdes|show|ncode|ndate|nlevel|nmon|nvar|nyear|ntime|npar|gradsdes|pardes)'

    self.libs        = self.getSupportedLibs()

  def __dir__(self):
    res = dir(type(self)) + list(self.__dict__.keys())
    res.extend(self.operators)
    return res

  def call(self,cmd,environment=None):
    if self.debug:
      print '# DEBUG ====================================================================='
      if None != environment:
        for k,v in environment.items():
          print "ENV: " + k + " = " + v
      print 'CALL:'+' '.join(cmd)
      print '# DEBUG ====================================================================='

    proc = subprocess.Popen(' '.join(cmd),
                            shell  = True,
                            stderr = subprocess.PIPE,
                            stdout = subprocess.PIPE,
                            env    = environment)
    retvals = proc.communicate()
    return {"stdout"     : retvals[0]
           ,"stderr"     : retvals[1]
           ,"returncode" : proc.returncode}

  def hasError(self,method_name,cmd,retvals):
    if (self.debug):
      print("RETURNCODE:"+retvals["returncode"].__str__())
    if ( 0 != retvals["returncode"] ):
      print("Error in calling operator " + method_name + " with:")
      print(">>> "+' '.join(cmd)+"<<<")
      print(retvals["stderr"])
      return True
    else:
      return False

  def __getattr__(self, method_name):

    @auto_doc(method_name, self)
    def get(self, *args,**kwargs):
      operator          = [method_name]
      operatorPrintsOut = re.search(self.outputOperatorsPattern,method_name)

      if args.__len__() != 0:
        for arg in args:
          operator.append(arg.__str__())

      #build the cdo command
      #1. the cdo command
      cmd = [self.CDO]
      #2. options
      if 'options' in kwargs:
          cmd += kwargs['options'].split()
      #3. operator(s)
      cmd.append(','.join(operator))
      #4. input files or operators
      if 'input' in kwargs:
        if isinstance(kwargs["input"], basestring):
            cmd.append(kwargs["input"])
        else:
            #we assume it's either a list, a tuple or any iterable.
            cmd += kwargs["input"]

      if not kwargs.__contains__("force"):
        kwargs["force"] = self.forceOutput

      if operatorPrintsOut:
        retvals = self.call(cmd)
        if ( not self.hasError(method_name,cmd,retvals) ):
          r = map(string.strip,retvals["stdout"].split(os.linesep))
          return r[:len(r)-1]
        else:
          if self.returnNoneOnError:
            return None
          else:
            raise CDOException(**retvals)
      else:
        if kwargs["force"] or \
           (kwargs.__contains__("output") and not os.path.isfile(kwargs["output"])):
          if not kwargs.__contains__("output") or None == kwargs["output"]:
            kwargs["output"] = self.tempfile.path()

          cmd.append(kwargs["output"])
          if kwargs.__contains__("env"):
            environment = kwargs["env"]
          else:
            environment = None

          retvals = self.call(cmd,environment=environment)
          if self.hasError(method_name,cmd,retvals):
            if self.returnNoneOnError:
              return None
            else:
              raise CDOException(**retvals)
        else:
          if self.debug:
            print("Use existing file'"+kwargs["output"]+"'")

      if not kwargs.__contains__("returnCdf"):
        kwargs["returnCdf"] = False

      if not None == kwargs.get("returnArray"):
        return self.readArray(kwargs["output"],kwargs["returnArray"])
      elif not None == kwargs.get("returnMaArray"):
        return self.readMaArray(kwargs["output"],kwargs["returnMaArray"])
      elif self.returnCdf or kwargs["returnCdf"]:
        if not self.returnCdf:
          self.loadCdf()
        return self.readCdf(kwargs["output"])
      else:
        return kwargs["output"]

    if ((method_name in self.__dict__) or (method_name in self.operators)):
      if self.debug:
        print("Found method:" + method_name)

      #cache the method for later
      setattr(self.__class__, method_name, get)
      return get.__get__(self)
    else:
      # If the method isn't in our dictionary, act normal.
      print("#=====================================================")
      print("Cannot find method:" + method_name)
      raise AttributeError, "Unknown method '" + method_name +"'!"

  def getOperators(self):
    import os
    proc = subprocess.Popen([self.CDO,'-h'],stderr = subprocess.PIPE,stdout = subprocess.PIPE)
    ret  = proc.communicate()
    l    = ret[1].find("Operators:")
    ops  = ret[1][l:-1].split(os.linesep)[1:-1]
    endI = ops.index('')
    s    = ' '.join(ops[:endI]).strip()
    s    = re.sub("\s+" , " ", s)
    return list(set(s.split(" ") + self.undocumentedOperators))

  def loadCdf(self):
    if self.cdfMod == "scipy":
      try:
        import scipy.io.netcdf as cdf
        self.cdf    = cdf
      except:
        print "Could not load scipy.io.netcdf - try to load nercdf4"
        self.cdfMod = "netcdf4" 

    if self.cdfMod == "netcdf4":
      try:
        import netCDF4 as cdf
        self.cdf    = cdf
      except:
        raise ImportError,"scipy or python-netcdf4 module is required to return numpy arrays."

  def getSupportedLibs(self,force=False):
    proc = subprocess.Popen(self.CDO + ' -V',
        shell  = True,
        stderr = subprocess.PIPE,
        stdout = subprocess.PIPE)
    retvals = proc.communicate()

    withs     = list(re.findall('(with|Features): (.*)',retvals[1])[0])[1].split(' ')
    libs      = re.findall('(\w+) library version : (\d+\.\d+\.\d+)',retvals[1])
    libraries = dict({})
    for w in withs:
      libraries[w.lower()] = True

    for lib in libs:
      l,v = lib
      libraries[l.lower()] = v

    return libraries

  def setReturnArray(self,value=True):
    self.returnCdf = value
    if value:
      self.loadCdf()


  def unsetReturnArray(self):
    self.setReturnArray(False)

  def hasCdo(self,path=None):
    if path is None:
      path = self.CDO

    if os.path.isfile(path) and os.access(path, os.X_OK):
      return True
    return False

  def checkCdo(self):
    if (self.hasCdo()):
      call = [self.CDO,' -V']
      proc = subprocess.Popen(' '.join(call),
          shell  = True,
          stderr = subprocess.PIPE,
          stdout = subprocess.PIPE)
      retvals = proc.communicate()
      print retvals

  def setCdo(self,value):
    self.CDO       = value
    self.operators = self.getOperators()

  def getCdo(self):
    return self.CDO

  def hasLib(self,lib):
    return lib in self.libs
    return false

  def libsVersion(self,lib):
    if not self.hasLib(lib):
      raise AttributeError, "Cdo does NOT have support for '#{lib}'"
    else:
      if True != self.libs[lib]:
        return self.libs[lib]
      else:
        print "No version information available about '" + lib + "'"
        return False

  #==================================================================
  # Addional operators:
  #------------------------------------------------------------------
  def module_version(self):
    '1.2.3'

  def version(self):
    # return CDO's version
    proc = subprocess.Popen([self.CDO,'-h'],stderr = subprocess.PIPE,stdout = subprocess.PIPE)
    ret  = proc.communicate()
    cdo_help   = ret[1]
    match = re.search("CDO version (\d.*), Copyright",cdo_help)
    return match.group(1)

  def boundaryLevels(self,**kwargs):
    ilevels         = map(float,self.showlevel(input = kwargs['input'])[0].split())
    bound_levels    = []
    bound_levels.insert(0,0)
    for i in range(1,len(ilevels)+1):
      bound_levels.insert(i,bound_levels[i-1] + 2*(ilevels[i-1]-bound_levels[i-1]))

    return bound_levels

  def thicknessOfLevels(self,**kwargs):
    bound_levels = self.boundaryLevels(**kwargs)
    delta_levels    = []
    for i in range(0,len(bound_levels)):
      v = bound_levels[i]
      if 0 == i:
        continue

      delta_levels.append(v - bound_levels[i-1])

    return delta_levels

  def readCdf(self,iFile):
    """Return a cdf handle created by the available cdf library. python-netcdf4 and scipy suported (default:scipy)"""
    if not self.returnCdf:
      self.loadCdf()

    if ( "scipy" == self.cdfMod):
      #making it compatible to older scipy versions
      fileObj =  self.cdf.netcdf_file(iFile, mode='r')
    elif ( "netcdf4" == self.cdfMod ):
      fileObj = self.cdf.Dataset(iFile)
    else:
      raise ImportError,"Could not import data from file '" + iFile + "'"

    retval = fileObj
    return retval

  def openCdf(self,iFile):
    """Return a cdf handle created by the available cdf library. python-netcdf4 and scipy suported (default:scipy)"""
    if not self.returnCdf:
      self.loadCdf()

    if ( "scipy" == self.cdfMod):
      #making it compatible to older scipy versions
      print("Use scipy")
      fileObj =  self.cdf.netcdf_file(iFile, mode='r+')
    elif ( "netcdf4" == self.cdfMod ):
      print("Use netcdf4")
      fileObj = self.cdf.Dataset(iFile,'r+')
    else:
      raise ImportError,"Could not import data from file '" + iFile + "'"

    retval = fileObj
    return retval

  def readArray(self,iFile,varname):
    """Direcly return a numpy array for a given variable name"""
    filehandle = self.readCdf(iFile)
    if varname in filehandle.variables:
      # return the data array
      return filehandle.variables[varname][:]
    else:
      print "Cannot find variable '" + varname +"'"
      return False

  def readMaArray(self,iFile,varname):
    """Create a masked array based on cdf's FillValue"""
    fileObj =  self.readCdf(iFile)

    #.data is not backwards compatible to old scipy versions, [:] is
    data = fileObj.variables[varname][:]

    # load numpy if available
    try:
      import numpy as np
    except:
      raise ImportError,"numpy is required to return masked arrays."

    if hasattr(fileObj.variables[varname],'_FillValue'):
      #return masked array
      retval = np.ma.array(data,mask=data == fileObj.variables[varname]._FillValue)
    else:
      #generate dummy mask which is always valid
      retval = np.ma.array(data,mask=data != data )

    return retval

# Helper module for easy temp file handling
class MyTempfile(object):

  __tempfiles = []

  def __init__(self):
    self.persistent_tempfile = False

  def __del__(self):
    # remove temporary files
    for filename in self.__class__.__tempfiles:
      if os.path.isfile(filename):
        os.remove(filename)

  def setPersist(self,value):
    self.persistent_tempfiles = value

  def path(self):
    if not self.persistent_tempfile:
      t = tempfile.NamedTemporaryFile(delete=True,prefix='cdoPy')
      self.__class__.__tempfiles.append(t.name)
      t.close()

      return t.name
    else:
      N =10000000 
      t = "_"+random.randint(N).__str__()



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 1.3.31
#
# Don't modify this file, modify the SWIG interface instead.
# This file is compatible with both classic and new-style classes.

import _CdiObj
import new
new_instancemethod = new.instancemethod
try:
    _swig_property = property
except NameError:
    pass # Python < 2.2 doesn't have 'property'.
def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "thisown"): return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'PySwigObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    if (name == "thisown"): return self.this.own()
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

def _swig_repr(self):
    try: strthis = "proxy of " + self.this.__repr__()
    except: strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


class PySwigIterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, PySwigIterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, PySwigIterator, name)
    def __init__(self): raise AttributeError, "No constructor defined"
    __repr__ = _swig_repr
    __swig_destroy__ = _CdiObj.delete_PySwigIterator
    __del__ = lambda self : None;
    def value(*args): return _CdiObj.PySwigIterator_value(*args)
    def incr(*args): return _CdiObj.PySwigIterator_incr(*args)
    def decr(*args): return _CdiObj.PySwigIterator_decr(*args)
    def distance(*args): return _CdiObj.PySwigIterator_distance(*args)
    def equal(*args): return _CdiObj.PySwigIterator_equal(*args)
    def copy(*args): return _CdiObj.PySwigIterator_copy(*args)
    def next(*args): return _CdiObj.PySwigIterator_next(*args)
    def previous(*args): return _CdiObj.PySwigIterator_previous(*args)
    def advance(*args): return _CdiObj.PySwigIterator_advance(*args)
    def __eq__(*args): return _CdiObj.PySwigIterator___eq__(*args)
    def __ne__(*args): return _CdiObj.PySwigIterator___ne__(*args)
    def __iadd__(*args): return _CdiObj.PySwigIterator___iadd__(*args)
    def __isub__(*args): return _CdiObj.PySwigIterator___isub__(*args)
    def __add__(*args): return _CdiObj.PySwigIterator___add__(*args)
    def __sub__(*args): return _CdiObj.PySwigIterator___sub__(*args)
    def __iter__(self): return self
PySwigIterator_swigregister = _CdiObj.PySwigIterator_swigregister
PySwigIterator_swigregister(PySwigIterator)

class IntVector(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, IntVector, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, IntVector, name)
    __repr__ = _swig_repr
    def iterator(*args): return _CdiObj.IntVector_iterator(*args)
    def __iter__(self): return self.iterator()
    def __nonzero__(*args): return _CdiObj.IntVector___nonzero__(*args)
    def __len__(*args): return _CdiObj.IntVector___len__(*args)
    def pop(*args): return _CdiObj.IntVector_pop(*args)
    def __getslice__(*args): return _CdiObj.IntVector___getslice__(*args)
    def __setslice__(*args): return _CdiObj.IntVector___setslice__(*args)
    def __delslice__(*args): return _CdiObj.IntVector___delslice__(*args)
    def __delitem__(*args): return _CdiObj.IntVector___delitem__(*args)
    def __getitem__(*args): return _CdiObj.IntVector___getitem__(*args)
    def __setitem__(*args): return _CdiObj.IntVector___setitem__(*args)
    def append(*args): return _CdiObj.IntVector_append(*args)
    def empty(*args): return _CdiObj.IntVector_empty(*args)
    def size(*args): return _CdiObj.IntVector_size(*args)
    def clear(*args): return _CdiObj.IntVector_clear(*args)
    def swap(*args): return _CdiObj.IntVector_swap(*args)
    def get_allocator(*args): return _CdiObj.IntVector_get_allocator(*args)
    def begin(*args): return _CdiObj.IntVector_begin(*args)
    def end(*args): return _CdiObj.IntVector_end(*args)
    def rbegin(*args): return _CdiObj.IntVector_rbegin(*args)
    def rend(*args): return _CdiObj.IntVector_rend(*args)
    def pop_back(*args): return _CdiObj.IntVector_pop_back(*args)
    def erase(*args): return _CdiObj.IntVector_erase(*args)
    def __init__(self, *args): 
        this = _CdiObj.new_IntVector(*args)
        try: self.this.append(this)
        except: self.this = this
    def push_back(*args): return _CdiObj.IntVector_push_back(*args)
    def front(*args): return _CdiObj.IntVector_front(*args)
    def back(*args): return _CdiObj.IntVector_back(*args)
    def assign(*args): return _CdiObj.IntVector_assign(*args)
    def resize(*args): return _CdiObj.IntVector_resize(*args)
    def insert(*args): return _CdiObj.IntVector_insert(*args)
    def reserve(*args): return _CdiObj.IntVector_reserve(*args)
    def capacity(*args): return _CdiObj.IntVector_capacity(*args)
    __swig_destroy__ = _CdiObj.delete_IntVector
    __del__ = lambda self : None;
IntVector_swigregister = _CdiObj.IntVector_swigregister
IntVector_swigregister(IntVector)

class DoubleVector(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, DoubleVector, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, DoubleVector, name)
    __repr__ = _swig_repr
    def iterator(*args): return _CdiObj.DoubleVector_iterator(*args)
    def __iter__(self): return self.iterator()
    def __nonzero__(*args): return _CdiObj.DoubleVector___nonzero__(*args)
    def __len__(*args): return _CdiObj.DoubleVector___len__(*args)
    def pop(*args): return _CdiObj.DoubleVector_pop(*args)
    def __getslice__(*args): return _CdiObj.DoubleVector___getslice__(*args)
    def __setslice__(*args): return _CdiObj.DoubleVector___setslice__(*args)
    def __delslice__(*args): return _CdiObj.DoubleVector___delslice__(*args)
    def __delitem__(*args): return _CdiObj.DoubleVector___delitem__(*args)
    def __getitem__(*args): return _CdiObj.DoubleVector___getitem__(*args)
    def __setitem__(*args): return _CdiObj.DoubleVector___setitem__(*args)
    def append(*args): return _CdiObj.DoubleVector_append(*args)
    def empty(*args): return _CdiObj.DoubleVector_empty(*args)
    def size(*args): return _CdiObj.DoubleVector_size(*args)
    def clear(*args): return _CdiObj.DoubleVector_clear(*args)
    def swap(*args): return _CdiObj.DoubleVector_swap(*args)
    def get_allocator(*args): return _CdiObj.DoubleVector_get_allocator(*args)
    def begin(*args): return _CdiObj.DoubleVector_begin(*args)
    def end(*args): return _CdiObj.DoubleVector_end(*args)
    def rbegin(*args): return _CdiObj.DoubleVector_rbegin(*args)
    def rend(*args): return _CdiObj.DoubleVector_rend(*args)
    def pop_back(*args): return _CdiObj.DoubleVector_pop_back(*args)
    def erase(*args): return _CdiObj.DoubleVector_erase(*args)
    def __init__(self, *args): 
        this = _CdiObj.new_DoubleVector(*args)
        try: self.this.append(this)
        except: self.this = this
    def push_back(*args): return _CdiObj.DoubleVector_push_back(*args)
    def front(*args): return _CdiObj.DoubleVector_front(*args)
    def back(*args): return _CdiObj.DoubleVector_back(*args)
    def assign(*args): return _CdiObj.DoubleVector_assign(*args)
    def resize(*args): return _CdiObj.DoubleVector_resize(*args)
    def insert(*args): return _CdiObj.DoubleVector_insert(*args)
    def reserve(*args): return _CdiObj.DoubleVector_reserve(*args)
    def capacity(*args): return _CdiObj.DoubleVector_capacity(*args)
    __swig_destroy__ = _CdiObj.delete_DoubleVector
    __del__ = lambda self : None;
DoubleVector_swigregister = _CdiObj.DoubleVector_swigregister
DoubleVector_swigregister(DoubleVector)

class DoubleDoubleVector(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, DoubleDoubleVector, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, DoubleDoubleVector, name)
    __repr__ = _swig_repr
    def iterator(*args): return _CdiObj.DoubleDoubleVector_iterator(*args)
    def __iter__(self): return self.iterator()
    def __nonzero__(*args): return _CdiObj.DoubleDoubleVector___nonzero__(*args)
    def __len__(*args): return _CdiObj.DoubleDoubleVector___len__(*args)
    def pop(*args): return _CdiObj.DoubleDoubleVector_pop(*args)
    def __getslice__(*args): return _CdiObj.DoubleDoubleVector___getslice__(*args)
    def __setslice__(*args): return _CdiObj.DoubleDoubleVector___setslice__(*args)
    def __delslice__(*args): return _CdiObj.DoubleDoubleVector___delslice__(*args)
    def __delitem__(*args): return _CdiObj.DoubleDoubleVector___delitem__(*args)
    def __getitem__(*args): return _CdiObj.DoubleDoubleVector___getitem__(*args)
    def __setitem__(*args): return _CdiObj.DoubleDoubleVector___setitem__(*args)
    def append(*args): return _CdiObj.DoubleDoubleVector_append(*args)
    def empty(*args): return _CdiObj.DoubleDoubleVector_empty(*args)
    def size(*args): return _CdiObj.DoubleDoubleVector_size(*args)
    def clear(*args): return _CdiObj.DoubleDoubleVector_clear(*args)
    def swap(*args): return _CdiObj.DoubleDoubleVector_swap(*args)
    def get_allocator(*args): return _CdiObj.DoubleDoubleVector_get_allocator(*args)
    def begin(*args): return _CdiObj.DoubleDoubleVector_begin(*args)
    def end(*args): return _CdiObj.DoubleDoubleVector_end(*args)
    def rbegin(*args): return _CdiObj.DoubleDoubleVector_rbegin(*args)
    def rend(*args): return _CdiObj.DoubleDoubleVector_rend(*args)
    def pop_back(*args): return _CdiObj.DoubleDoubleVector_pop_back(*args)
    def erase(*args): return _CdiObj.DoubleDoubleVector_erase(*args)
    def __init__(self, *args): 
        this = _CdiObj.new_DoubleDoubleVector(*args)
        try: self.this.append(this)
        except: self.this = this
    def push_back(*args): return _CdiObj.DoubleDoubleVector_push_back(*args)
    def front(*args): return _CdiObj.DoubleDoubleVector_front(*args)
    def back(*args): return _CdiObj.DoubleDoubleVector_back(*args)
    def assign(*args): return _CdiObj.DoubleDoubleVector_assign(*args)
    def resize(*args): return _CdiObj.DoubleDoubleVector_resize(*args)
    def insert(*args): return _CdiObj.DoubleDoubleVector_insert(*args)
    def reserve(*args): return _CdiObj.DoubleDoubleVector_reserve(*args)
    def capacity(*args): return _CdiObj.DoubleDoubleVector_capacity(*args)
    __swig_destroy__ = _CdiObj.delete_DoubleDoubleVector
    __del__ = lambda self : None;
DoubleDoubleVector_swigregister = _CdiObj.DoubleDoubleVector_swigregister
DoubleDoubleVector_swigregister(DoubleDoubleVector)

class StringVector(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, StringVector, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, StringVector, name)
    __repr__ = _swig_repr
    def iterator(*args): return _CdiObj.StringVector_iterator(*args)
    def __iter__(self): return self.iterator()
    def __nonzero__(*args): return _CdiObj.StringVector___nonzero__(*args)
    def __len__(*args): return _CdiObj.StringVector___len__(*args)
    def pop(*args): return _CdiObj.StringVector_pop(*args)
    def __getslice__(*args): return _CdiObj.StringVector___getslice__(*args)
    def __setslice__(*args): return _CdiObj.StringVector___setslice__(*args)
    def __delslice__(*args): return _CdiObj.StringVector___delslice__(*args)
    def __delitem__(*args): return _CdiObj.StringVector___delitem__(*args)
    def __getitem__(*args): return _CdiObj.StringVector___getitem__(*args)
    def __setitem__(*args): return _CdiObj.StringVector___setitem__(*args)
    def append(*args): return _CdiObj.StringVector_append(*args)
    def empty(*args): return _CdiObj.StringVector_empty(*args)
    def size(*args): return _CdiObj.StringVector_size(*args)
    def clear(*args): return _CdiObj.StringVector_clear(*args)
    def swap(*args): return _CdiObj.StringVector_swap(*args)
    def get_allocator(*args): return _CdiObj.StringVector_get_allocator(*args)
    def begin(*args): return _CdiObj.StringVector_begin(*args)
    def end(*args): return _CdiObj.StringVector_end(*args)
    def rbegin(*args): return _CdiObj.StringVector_rbegin(*args)
    def rend(*args): return _CdiObj.StringVector_rend(*args)
    def pop_back(*args): return _CdiObj.StringVector_pop_back(*args)
    def erase(*args): return _CdiObj.StringVector_erase(*args)
    def __init__(self, *args): 
        this = _CdiObj.new_StringVector(*args)
        try: self.this.append(this)
        except: self.this = this
    def push_back(*args): return _CdiObj.StringVector_push_back(*args)
    def front(*args): return _CdiObj.StringVector_front(*args)
    def back(*args): return _CdiObj.StringVector_back(*args)
    def assign(*args): return _CdiObj.StringVector_assign(*args)
    def resize(*args): return _CdiObj.StringVector_resize(*args)
    def insert(*args): return _CdiObj.StringVector_insert(*args)
    def reserve(*args): return _CdiObj.StringVector_reserve(*args)
    def capacity(*args): return _CdiObj.StringVector_capacity(*args)
    __swig_destroy__ = _CdiObj.delete_StringVector
    __del__ = lambda self : None;
StringVector_swigregister = _CdiObj.StringVector_swigregister
StringVector_swigregister(StringVector)

class VarsVector(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, VarsVector, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, VarsVector, name)
    __repr__ = _swig_repr
    def iterator(*args): return _CdiObj.VarsVector_iterator(*args)
    def __iter__(self): return self.iterator()
    def __nonzero__(*args): return _CdiObj.VarsVector___nonzero__(*args)
    def __len__(*args): return _CdiObj.VarsVector___len__(*args)
    def pop(*args): return _CdiObj.VarsVector_pop(*args)
    def __getslice__(*args): return _CdiObj.VarsVector___getslice__(*args)
    def __setslice__(*args): return _CdiObj.VarsVector___setslice__(*args)
    def __delslice__(*args): return _CdiObj.VarsVector___delslice__(*args)
    def __delitem__(*args): return _CdiObj.VarsVector___delitem__(*args)
    def __getitem__(*args): return _CdiObj.VarsVector___getitem__(*args)
    def __setitem__(*args): return _CdiObj.VarsVector___setitem__(*args)
    def append(*args): return _CdiObj.VarsVector_append(*args)
    def empty(*args): return _CdiObj.VarsVector_empty(*args)
    def size(*args): return _CdiObj.VarsVector_size(*args)
    def clear(*args): return _CdiObj.VarsVector_clear(*args)
    def swap(*args): return _CdiObj.VarsVector_swap(*args)
    def get_allocator(*args): return _CdiObj.VarsVector_get_allocator(*args)
    def begin(*args): return _CdiObj.VarsVector_begin(*args)
    def end(*args): return _CdiObj.VarsVector_end(*args)
    def rbegin(*args): return _CdiObj.VarsVector_rbegin(*args)
    def rend(*args): return _CdiObj.VarsVector_rend(*args)
    def pop_back(*args): return _CdiObj.VarsVector_pop_back(*args)
    def erase(*args): return _CdiObj.VarsVector_erase(*args)
    def __init__(self, *args): 
        this = _CdiObj.new_VarsVector(*args)
        try: self.this.append(this)
        except: self.this = this
    def push_back(*args): return _CdiObj.VarsVector_push_back(*args)
    def front(*args): return _CdiObj.VarsVector_front(*args)
    def back(*args): return _CdiObj.VarsVector_back(*args)
    def assign(*args): return _CdiObj.VarsVector_assign(*args)
    def resize(*args): return _CdiObj.VarsVector_resize(*args)
    def insert(*args): return _CdiObj.VarsVector_insert(*args)
    def reserve(*args): return _CdiObj.VarsVector_reserve(*args)
    def capacity(*args): return _CdiObj.VarsVector_capacity(*args)
    __swig_destroy__ = _CdiObj.delete_VarsVector
    __del__ = lambda self : None;
VarsVector_swigregister = _CdiObj.VarsVector_swigregister
VarsVector_swigregister(VarsVector)

class VarsMap(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, VarsMap, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, VarsMap, name)
    __repr__ = _swig_repr
    def iterator(*args): return _CdiObj.VarsMap_iterator(*args)
    def __iter__(self): return self.iterator()
    def __nonzero__(*args): return _CdiObj.VarsMap___nonzero__(*args)
    def __len__(*args): return _CdiObj.VarsMap___len__(*args)
    def __getitem__(*args): return _CdiObj.VarsMap___getitem__(*args)
    def __delitem__(*args): return _CdiObj.VarsMap___delitem__(*args)
    def has_key(*args): return _CdiObj.VarsMap_has_key(*args)
    def keys(*args): return _CdiObj.VarsMap_keys(*args)
    def values(*args): return _CdiObj.VarsMap_values(*args)
    def items(*args): return _CdiObj.VarsMap_items(*args)
    def __contains__(*args): return _CdiObj.VarsMap___contains__(*args)
    def key_iterator(*args): return _CdiObj.VarsMap_key_iterator(*args)
    def value_iterator(*args): return _CdiObj.VarsMap_value_iterator(*args)
    def __iter__(self): return self.key_iterator()
    def iterkeys(self): return self.key_iterator()
    def itervalues(self): return self.value_iterator()
    def iteritems(self): return self.iterator()
    def __setitem__(*args): return _CdiObj.VarsMap___setitem__(*args)
    def __init__(self, *args): 
        this = _CdiObj.new_VarsMap(*args)
        try: self.this.append(this)
        except: self.this = this
    def empty(*args): return _CdiObj.VarsMap_empty(*args)
    def size(*args): return _CdiObj.VarsMap_size(*args)
    def clear(*args): return _CdiObj.VarsMap_clear(*args)
    def swap(*args): return _CdiObj.VarsMap_swap(*args)
    def get_allocator(*args): return _CdiObj.VarsMap_get_allocator(*args)
    def begin(*args): return _CdiObj.VarsMap_begin(*args)
    def end(*args): return _CdiObj.VarsMap_end(*args)
    def rbegin(*args): return _CdiObj.VarsMap_rbegin(*args)
    def rend(*args): return _CdiObj.VarsMap_rend(*args)
    def count(*args): return _CdiObj.VarsMap_count(*args)
    def erase(*args): return _CdiObj.VarsMap_erase(*args)
    def find(*args): return _CdiObj.VarsMap_find(*args)
    def lower_bound(*args): return _CdiObj.VarsMap_lower_bound(*args)
    def upper_bound(*args): return _CdiObj.VarsMap_upper_bound(*args)
    __swig_destroy__ = _CdiObj.delete_VarsMap
    __del__ = lambda self : None;
VarsMap_swigregister = _CdiObj.VarsMap_swigregister
VarsMap_swigregister(VarsMap)

class VarsByCode(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, VarsByCode, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, VarsByCode, name)
    __repr__ = _swig_repr
    def iterator(*args): return _CdiObj.VarsByCode_iterator(*args)
    def __iter__(self): return self.iterator()
    def __nonzero__(*args): return _CdiObj.VarsByCode___nonzero__(*args)
    def __len__(*args): return _CdiObj.VarsByCode___len__(*args)
    def __getitem__(*args): return _CdiObj.VarsByCode___getitem__(*args)
    def __delitem__(*args): return _CdiObj.VarsByCode___delitem__(*args)
    def has_key(*args): return _CdiObj.VarsByCode_has_key(*args)
    def keys(*args): return _CdiObj.VarsByCode_keys(*args)
    def values(*args): return _CdiObj.VarsByCode_values(*args)
    def items(*args): return _CdiObj.VarsByCode_items(*args)
    def __contains__(*args): return _CdiObj.VarsByCode___contains__(*args)
    def key_iterator(*args): return _CdiObj.VarsByCode_key_iterator(*args)
    def value_iterator(*args): return _CdiObj.VarsByCode_value_iterator(*args)
    def __iter__(self): return self.key_iterator()
    def iterkeys(self): return self.key_iterator()
    def itervalues(self): return self.value_iterator()
    def iteritems(self): return self.iterator()
    def __setitem__(*args): return _CdiObj.VarsByCode___setitem__(*args)
    def __init__(self, *args): 
        this = _CdiObj.new_VarsByCode(*args)
        try: self.this.append(this)
        except: self.this = this
    def empty(*args): return _CdiObj.VarsByCode_empty(*args)
    def size(*args): return _CdiObj.VarsByCode_size(*args)
    def clear(*args): return _CdiObj.VarsByCode_clear(*args)
    def swap(*args): return _CdiObj.VarsByCode_swap(*args)
    def get_allocator(*args): return _CdiObj.VarsByCode_get_allocator(*args)
    def begin(*args): return _CdiObj.VarsByCode_begin(*args)
    def end(*args): return _CdiObj.VarsByCode_end(*args)
    def rbegin(*args): return _CdiObj.VarsByCode_rbegin(*args)
    def rend(*args): return _CdiObj.VarsByCode_rend(*args)
    def count(*args): return _CdiObj.VarsByCode_count(*args)
    def erase(*args): return _CdiObj.VarsByCode_erase(*args)
    def find(*args): return _CdiObj.VarsByCode_find(*args)
    def lower_bound(*args): return _CdiObj.VarsByCode_lower_bound(*args)
    def upper_bound(*args): return _CdiObj.VarsByCode_upper_bound(*args)
    __swig_destroy__ = _CdiObj.delete_VarsByCode
    __del__ = lambda self : None;
VarsByCode_swigregister = _CdiObj.VarsByCode_swigregister
VarsByCode_swigregister(VarsByCode)

class TaxesMap(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, TaxesMap, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, TaxesMap, name)
    __repr__ = _swig_repr
    def iterator(*args): return _CdiObj.TaxesMap_iterator(*args)
    def __iter__(self): return self.iterator()
    def __nonzero__(*args): return _CdiObj.TaxesMap___nonzero__(*args)
    def __len__(*args): return _CdiObj.TaxesMap___len__(*args)
    def __getitem__(*args): return _CdiObj.TaxesMap___getitem__(*args)
    def __delitem__(*args): return _CdiObj.TaxesMap___delitem__(*args)
    def has_key(*args): return _CdiObj.TaxesMap_has_key(*args)
    def keys(*args): return _CdiObj.TaxesMap_keys(*args)
    def values(*args): return _CdiObj.TaxesMap_values(*args)
    def items(*args): return _CdiObj.TaxesMap_items(*args)
    def __contains__(*args): return _CdiObj.TaxesMap___contains__(*args)
    def key_iterator(*args): return _CdiObj.TaxesMap_key_iterator(*args)
    def value_iterator(*args): return _CdiObj.TaxesMap_value_iterator(*args)
    def __iter__(self): return self.key_iterator()
    def iterkeys(self): return self.key_iterator()
    def itervalues(self): return self.value_iterator()
    def iteritems(self): return self.iterator()
    def __setitem__(*args): return _CdiObj.TaxesMap___setitem__(*args)
    def __init__(self, *args): 
        this = _CdiObj.new_TaxesMap(*args)
        try: self.this.append(this)
        except: self.this = this
    def empty(*args): return _CdiObj.TaxesMap_empty(*args)
    def size(*args): return _CdiObj.TaxesMap_size(*args)
    def clear(*args): return _CdiObj.TaxesMap_clear(*args)
    def swap(*args): return _CdiObj.TaxesMap_swap(*args)
    def get_allocator(*args): return _CdiObj.TaxesMap_get_allocator(*args)
    def begin(*args): return _CdiObj.TaxesMap_begin(*args)
    def end(*args): return _CdiObj.TaxesMap_end(*args)
    def rbegin(*args): return _CdiObj.TaxesMap_rbegin(*args)
    def rend(*args): return _CdiObj.TaxesMap_rend(*args)
    def count(*args): return _CdiObj.TaxesMap_count(*args)
    def erase(*args): return _CdiObj.TaxesMap_erase(*args)
    def find(*args): return _CdiObj.TaxesMap_find(*args)
    def lower_bound(*args): return _CdiObj.TaxesMap_lower_bound(*args)
    def upper_bound(*args): return _CdiObj.TaxesMap_upper_bound(*args)
    __swig_destroy__ = _CdiObj.delete_TaxesMap
    __del__ = lambda self : None;
TaxesMap_swigregister = _CdiObj.TaxesMap_swigregister
TaxesMap_swigregister(TaxesMap)

class ZaxesMap(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, ZaxesMap, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, ZaxesMap, name)
    __repr__ = _swig_repr
    def iterator(*args): return _CdiObj.ZaxesMap_iterator(*args)
    def __iter__(self): return self.iterator()
    def __nonzero__(*args): return _CdiObj.ZaxesMap___nonzero__(*args)
    def __len__(*args): return _CdiObj.ZaxesMap___len__(*args)
    def __getitem__(*args): return _CdiObj.ZaxesMap___getitem__(*args)
    def __delitem__(*args): return _CdiObj.ZaxesMap___delitem__(*args)
    def has_key(*args): return _CdiObj.ZaxesMap_has_key(*args)
    def keys(*args): return _CdiObj.ZaxesMap_keys(*args)
    def values(*args): return _CdiObj.ZaxesMap_values(*args)
    def items(*args): return _CdiObj.ZaxesMap_items(*args)
    def __contains__(*args): return _CdiObj.ZaxesMap___contains__(*args)
    def key_iterator(*args): return _CdiObj.ZaxesMap_key_iterator(*args)
    def value_iterator(*args): return _CdiObj.ZaxesMap_value_iterator(*args)
    def __iter__(self): return self.key_iterator()
    def iterkeys(self): return self.key_iterator()
    def itervalues(self): return self.value_iterator()
    def iteritems(self): return self.iterator()
    def __setitem__(*args): return _CdiObj.ZaxesMap___setitem__(*args)
    def __init__(self, *args): 
        this = _CdiObj.new_ZaxesMap(*args)
        try: self.this.append(this)
        except: self.this = this
    def empty(*args): return _CdiObj.ZaxesMap_empty(*args)
    def size(*args): return _CdiObj.ZaxesMap_size(*args)
    def clear(*args): return _CdiObj.ZaxesMap_clear(*args)
    def swap(*args): return _CdiObj.ZaxesMap_swap(*args)
    def get_allocator(*args): return _CdiObj.ZaxesMap_get_allocator(*args)
    def begin(*args): return _CdiObj.ZaxesMap_begin(*args)
    def end(*args): return _CdiObj.ZaxesMap_end(*args)
    def rbegin(*args): return _CdiObj.ZaxesMap_rbegin(*args)
    def rend(*args): return _CdiObj.ZaxesMap_rend(*args)
    def count(*args): return _CdiObj.ZaxesMap_count(*args)
    def erase(*args): return _CdiObj.ZaxesMap_erase(*args)
    def find(*args): return _CdiObj.ZaxesMap_find(*args)
    def lower_bound(*args): return _CdiObj.ZaxesMap_lower_bound(*args)
    def upper_bound(*args): return _CdiObj.ZaxesMap_upper_bound(*args)
    __swig_destroy__ = _CdiObj.delete_ZaxesMap
    __del__ = lambda self : None;
ZaxesMap_swigregister = _CdiObj.ZaxesMap_swigregister
ZaxesMap_swigregister(ZaxesMap)

class GridsMap(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, GridsMap, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, GridsMap, name)
    __repr__ = _swig_repr
    def iterator(*args): return _CdiObj.GridsMap_iterator(*args)
    def __iter__(self): return self.iterator()
    def __nonzero__(*args): return _CdiObj.GridsMap___nonzero__(*args)
    def __len__(*args): return _CdiObj.GridsMap___len__(*args)
    def __getitem__(*args): return _CdiObj.GridsMap___getitem__(*args)
    def __delitem__(*args): return _CdiObj.GridsMap___delitem__(*args)
    def has_key(*args): return _CdiObj.GridsMap_has_key(*args)
    def keys(*args): return _CdiObj.GridsMap_keys(*args)
    def values(*args): return _CdiObj.GridsMap_values(*args)
    def items(*args): return _CdiObj.GridsMap_items(*args)
    def __contains__(*args): return _CdiObj.GridsMap___contains__(*args)
    def key_iterator(*args): return _CdiObj.GridsMap_key_iterator(*args)
    def value_iterator(*args): return _CdiObj.GridsMap_value_iterator(*args)
    def __iter__(self): return self.key_iterator()
    def iterkeys(self): return self.key_iterator()
    def itervalues(self): return self.value_iterator()
    def iteritems(self): return self.iterator()
    def __setitem__(*args): return _CdiObj.GridsMap___setitem__(*args)
    def __init__(self, *args): 
        this = _CdiObj.new_GridsMap(*args)
        try: self.this.append(this)
        except: self.this = this
    def empty(*args): return _CdiObj.GridsMap_empty(*args)
    def size(*args): return _CdiObj.GridsMap_size(*args)
    def clear(*args): return _CdiObj.GridsMap_clear(*args)
    def swap(*args): return _CdiObj.GridsMap_swap(*args)
    def get_allocator(*args): return _CdiObj.GridsMap_get_allocator(*args)
    def begin(*args): return _CdiObj.GridsMap_begin(*args)
    def end(*args): return _CdiObj.GridsMap_end(*args)
    def rbegin(*args): return _CdiObj.GridsMap_rbegin(*args)
    def rend(*args): return _CdiObj.GridsMap_rend(*args)
    def count(*args): return _CdiObj.GridsMap_count(*args)
    def erase(*args): return _CdiObj.GridsMap_erase(*args)
    def find(*args): return _CdiObj.GridsMap_find(*args)
    def lower_bound(*args): return _CdiObj.GridsMap_lower_bound(*args)
    def upper_bound(*args): return _CdiObj.GridsMap_upper_bound(*args)
    __swig_destroy__ = _CdiObj.delete_GridsMap
    __del__ = lambda self : None;
GridsMap_swigregister = _CdiObj.GridsMap_swigregister
GridsMap_swigregister(GridsMap)

CHARSIZE = _CdiObj.CHARSIZE
class CdiGrid(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, CdiGrid, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, CdiGrid, name)
    __repr__ = _swig_repr
    def __init__(self, *args): 
        this = _CdiObj.new_CdiGrid(*args)
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _CdiObj.delete_CdiGrid
    __del__ = lambda self : None;
    __swig_setmethods__["gridID"] = _CdiObj.CdiGrid_gridID_set
    __swig_getmethods__["gridID"] = _CdiObj.CdiGrid_gridID_get
    if _newclass:gridID = _swig_property(_CdiObj.CdiGrid_gridID_get, _CdiObj.CdiGrid_gridID_set)
    __swig_setmethods__["type"] = _CdiObj.CdiGrid_type_set
    __swig_getmethods__["type"] = _CdiObj.CdiGrid_type_get
    if _newclass:type = _swig_property(_CdiObj.CdiGrid_type_get, _CdiObj.CdiGrid_type_set)
    __swig_setmethods__["size"] = _CdiObj.CdiGrid_size_set
    __swig_getmethods__["size"] = _CdiObj.CdiGrid_size_get
    if _newclass:size = _swig_property(_CdiObj.CdiGrid_size_get, _CdiObj.CdiGrid_size_set)
    __swig_setmethods__["xsize"] = _CdiObj.CdiGrid_xsize_set
    __swig_getmethods__["xsize"] = _CdiObj.CdiGrid_xsize_get
    if _newclass:xsize = _swig_property(_CdiObj.CdiGrid_xsize_get, _CdiObj.CdiGrid_xsize_set)
    __swig_setmethods__["ysize"] = _CdiObj.CdiGrid_ysize_set
    __swig_getmethods__["ysize"] = _CdiObj.CdiGrid_ysize_get
    if _newclass:ysize = _swig_property(_CdiObj.CdiGrid_ysize_get, _CdiObj.CdiGrid_ysize_set)
    __swig_setmethods__["prec"] = _CdiObj.CdiGrid_prec_set
    __swig_getmethods__["prec"] = _CdiObj.CdiGrid_prec_get
    if _newclass:prec = _swig_property(_CdiObj.CdiGrid_prec_get, _CdiObj.CdiGrid_prec_set)
    __swig_setmethods__["ncorner"] = _CdiObj.CdiGrid_ncorner_set
    __swig_getmethods__["ncorner"] = _CdiObj.CdiGrid_ncorner_get
    if _newclass:ncorner = _swig_property(_CdiObj.CdiGrid_ncorner_get, _CdiObj.CdiGrid_ncorner_set)
    __swig_setmethods__["hasXValues"] = _CdiObj.CdiGrid_hasXValues_set
    __swig_getmethods__["hasXValues"] = _CdiObj.CdiGrid_hasXValues_get
    if _newclass:hasXValues = _swig_property(_CdiObj.CdiGrid_hasXValues_get, _CdiObj.CdiGrid_hasXValues_set)
    __swig_setmethods__["hasYValues"] = _CdiObj.CdiGrid_hasYValues_set
    __swig_getmethods__["hasYValues"] = _CdiObj.CdiGrid_hasYValues_get
    if _newclass:hasYValues = _swig_property(_CdiObj.CdiGrid_hasYValues_get, _CdiObj.CdiGrid_hasYValues_set)
    __swig_setmethods__["hasBounds"] = _CdiObj.CdiGrid_hasBounds_set
    __swig_getmethods__["hasBounds"] = _CdiObj.CdiGrid_hasBounds_get
    if _newclass:hasBounds = _swig_property(_CdiObj.CdiGrid_hasBounds_get, _CdiObj.CdiGrid_hasBounds_set)
    __swig_setmethods__["xvalues"] = _CdiObj.CdiGrid_xvalues_set
    __swig_getmethods__["xvalues"] = _CdiObj.CdiGrid_xvalues_get
    if _newclass:xvalues = _swig_property(_CdiObj.CdiGrid_xvalues_get, _CdiObj.CdiGrid_xvalues_set)
    __swig_setmethods__["yvalues"] = _CdiObj.CdiGrid_yvalues_set
    __swig_getmethods__["yvalues"] = _CdiObj.CdiGrid_yvalues_get
    if _newclass:yvalues = _swig_property(_CdiObj.CdiGrid_yvalues_get, _CdiObj.CdiGrid_yvalues_set)
    __swig_setmethods__["xbounds"] = _CdiObj.CdiGrid_xbounds_set
    __swig_getmethods__["xbounds"] = _CdiObj.CdiGrid_xbounds_get
    if _newclass:xbounds = _swig_property(_CdiObj.CdiGrid_xbounds_get, _CdiObj.CdiGrid_xbounds_set)
    __swig_setmethods__["ybounds"] = _CdiObj.CdiGrid_ybounds_set
    __swig_getmethods__["ybounds"] = _CdiObj.CdiGrid_ybounds_get
    if _newclass:ybounds = _swig_property(_CdiObj.CdiGrid_ybounds_get, _CdiObj.CdiGrid_ybounds_set)
    __swig_setmethods__["xname"] = _CdiObj.CdiGrid_xname_set
    __swig_getmethods__["xname"] = _CdiObj.CdiGrid_xname_get
    if _newclass:xname = _swig_property(_CdiObj.CdiGrid_xname_get, _CdiObj.CdiGrid_xname_set)
    __swig_setmethods__["xlongname"] = _CdiObj.CdiGrid_xlongname_set
    __swig_getmethods__["xlongname"] = _CdiObj.CdiGrid_xlongname_get
    if _newclass:xlongname = _swig_property(_CdiObj.CdiGrid_xlongname_get, _CdiObj.CdiGrid_xlongname_set)
    __swig_setmethods__["xstdname"] = _CdiObj.CdiGrid_xstdname_set
    __swig_getmethods__["xstdname"] = _CdiObj.CdiGrid_xstdname_get
    if _newclass:xstdname = _swig_property(_CdiObj.CdiGrid_xstdname_get, _CdiObj.CdiGrid_xstdname_set)
    __swig_setmethods__["xunits"] = _CdiObj.CdiGrid_xunits_set
    __swig_getmethods__["xunits"] = _CdiObj.CdiGrid_xunits_get
    if _newclass:xunits = _swig_property(_CdiObj.CdiGrid_xunits_get, _CdiObj.CdiGrid_xunits_set)
    __swig_setmethods__["yname"] = _CdiObj.CdiGrid_yname_set
    __swig_getmethods__["yname"] = _CdiObj.CdiGrid_yname_get
    if _newclass:yname = _swig_property(_CdiObj.CdiGrid_yname_get, _CdiObj.CdiGrid_yname_set)
    __swig_setmethods__["ylongname"] = _CdiObj.CdiGrid_ylongname_set
    __swig_getmethods__["ylongname"] = _CdiObj.CdiGrid_ylongname_get
    if _newclass:ylongname = _swig_property(_CdiObj.CdiGrid_ylongname_get, _CdiObj.CdiGrid_ylongname_set)
    __swig_setmethods__["ystdname"] = _CdiObj.CdiGrid_ystdname_set
    __swig_getmethods__["ystdname"] = _CdiObj.CdiGrid_ystdname_get
    if _newclass:ystdname = _swig_property(_CdiObj.CdiGrid_ystdname_get, _CdiObj.CdiGrid_ystdname_set)
    __swig_setmethods__["yunits"] = _CdiObj.CdiGrid_yunits_set
    __swig_getmethods__["yunits"] = _CdiObj.CdiGrid_yunits_get
    if _newclass:yunits = _swig_property(_CdiObj.CdiGrid_yunits_get, _CdiObj.CdiGrid_yunits_set)
    __swig_setmethods__["name"] = _CdiObj.CdiGrid_name_set
    __swig_getmethods__["name"] = _CdiObj.CdiGrid_name_get
    if _newclass:name = _swig_property(_CdiObj.CdiGrid_name_get, _CdiObj.CdiGrid_name_set)
    def getValues(*args): return _CdiObj.CdiGrid_getValues(*args)
    def getBounds(*args): return _CdiObj.CdiGrid_getBounds(*args)
    def getValuesAsPointer(*args): return _CdiObj.CdiGrid_getValuesAsPointer(*args)
    def getBoundsAsPointer(*args): return _CdiObj.CdiGrid_getBoundsAsPointer(*args)
    def getFloatVals(*args): return _CdiObj.CdiGrid_getFloatVals(*args)
    def getFloatBounds(*args): return _CdiObj.CdiGrid_getFloatBounds(*args)
CdiGrid_swigregister = _CdiObj.CdiGrid_swigregister
CdiGrid_swigregister(CdiGrid)

class CdiTaxis(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, CdiTaxis, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, CdiTaxis, name)
    __repr__ = _swig_repr
    def __init__(self, *args): 
        this = _CdiObj.new_CdiTaxis(*args)
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _CdiObj.delete_CdiTaxis
    __del__ = lambda self : None;
    __swig_setmethods__["taxisID"] = _CdiObj.CdiTaxis_taxisID_set
    __swig_getmethods__["taxisID"] = _CdiObj.CdiTaxis_taxisID_get
    if _newclass:taxisID = _swig_property(_CdiObj.CdiTaxis_taxisID_get, _CdiObj.CdiTaxis_taxisID_set)
    __swig_setmethods__["ntsteps"] = _CdiObj.CdiTaxis_ntsteps_set
    __swig_getmethods__["ntsteps"] = _CdiObj.CdiTaxis_ntsteps_get
    if _newclass:ntsteps = _swig_property(_CdiObj.CdiTaxis_ntsteps_get, _CdiObj.CdiTaxis_ntsteps_set)
    __swig_setmethods__["unit"] = _CdiObj.CdiTaxis_unit_set
    __swig_getmethods__["unit"] = _CdiObj.CdiTaxis_unit_get
    if _newclass:unit = _swig_property(_CdiObj.CdiTaxis_unit_get, _CdiObj.CdiTaxis_unit_set)
    __swig_setmethods__["rdate"] = _CdiObj.CdiTaxis_rdate_set
    __swig_getmethods__["rdate"] = _CdiObj.CdiTaxis_rdate_get
    if _newclass:rdate = _swig_property(_CdiObj.CdiTaxis_rdate_get, _CdiObj.CdiTaxis_rdate_set)
    __swig_setmethods__["rtime"] = _CdiObj.CdiTaxis_rtime_set
    __swig_getmethods__["rtime"] = _CdiObj.CdiTaxis_rtime_get
    if _newclass:rtime = _swig_property(_CdiObj.CdiTaxis_rtime_get, _CdiObj.CdiTaxis_rtime_set)
    __swig_setmethods__["vdate"] = _CdiObj.CdiTaxis_vdate_set
    __swig_getmethods__["vdate"] = _CdiObj.CdiTaxis_vdate_get
    if _newclass:vdate = _swig_property(_CdiObj.CdiTaxis_vdate_get, _CdiObj.CdiTaxis_vdate_set)
    __swig_setmethods__["vtime"] = _CdiObj.CdiTaxis_vtime_set
    __swig_getmethods__["vtime"] = _CdiObj.CdiTaxis_vtime_get
    if _newclass:vtime = _swig_property(_CdiObj.CdiTaxis_vtime_get, _CdiObj.CdiTaxis_vtime_set)
    __swig_setmethods__["type"] = _CdiObj.CdiTaxis_type_set
    __swig_getmethods__["type"] = _CdiObj.CdiTaxis_type_get
    if _newclass:type = _swig_property(_CdiObj.CdiTaxis_type_get, _CdiObj.CdiTaxis_type_set)
    __swig_setmethods__["calendar"] = _CdiObj.CdiTaxis_calendar_set
    __swig_getmethods__["calendar"] = _CdiObj.CdiTaxis_calendar_get
    if _newclass:calendar = _swig_property(_CdiObj.CdiTaxis_calendar_get, _CdiObj.CdiTaxis_calendar_set)
    __swig_setmethods__["hasBounds"] = _CdiObj.CdiTaxis_hasBounds_set
    __swig_getmethods__["hasBounds"] = _CdiObj.CdiTaxis_hasBounds_get
    if _newclass:hasBounds = _swig_property(_CdiObj.CdiTaxis_hasBounds_get, _CdiObj.CdiTaxis_hasBounds_set)
    __swig_setmethods__["name"] = _CdiObj.CdiTaxis_name_set
    __swig_getmethods__["name"] = _CdiObj.CdiTaxis_name_get
    if _newclass:name = _swig_property(_CdiObj.CdiTaxis_name_get, _CdiObj.CdiTaxis_name_set)
    __swig_setmethods__["unitname"] = _CdiObj.CdiTaxis_unitname_set
    __swig_getmethods__["unitname"] = _CdiObj.CdiTaxis_unitname_get
    if _newclass:unitname = _swig_property(_CdiObj.CdiTaxis_unitname_get, _CdiObj.CdiTaxis_unitname_set)
CdiTaxis_swigregister = _CdiObj.CdiTaxis_swigregister
CdiTaxis_swigregister(CdiTaxis)

class CdiZaxis(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, CdiZaxis, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, CdiZaxis, name)
    __repr__ = _swig_repr
    def __init__(self, *args): 
        this = _CdiObj.new_CdiZaxis(*args)
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _CdiObj.delete_CdiZaxis
    __del__ = lambda self : None;
    __swig_setmethods__["zaxisID"] = _CdiObj.CdiZaxis_zaxisID_set
    __swig_getmethods__["zaxisID"] = _CdiObj.CdiZaxis_zaxisID_get
    if _newclass:zaxisID = _swig_property(_CdiObj.CdiZaxis_zaxisID_get, _CdiObj.CdiZaxis_zaxisID_set)
    __swig_setmethods__["type"] = _CdiObj.CdiZaxis_type_set
    __swig_getmethods__["type"] = _CdiObj.CdiZaxis_type_get
    if _newclass:type = _swig_property(_CdiObj.CdiZaxis_type_get, _CdiObj.CdiZaxis_type_set)
    __swig_setmethods__["ltype"] = _CdiObj.CdiZaxis_ltype_set
    __swig_getmethods__["ltype"] = _CdiObj.CdiZaxis_ltype_get
    if _newclass:ltype = _swig_property(_CdiObj.CdiZaxis_ltype_get, _CdiObj.CdiZaxis_ltype_set)
    __swig_setmethods__["size"] = _CdiObj.CdiZaxis_size_set
    __swig_getmethods__["size"] = _CdiObj.CdiZaxis_size_get
    if _newclass:size = _swig_property(_CdiObj.CdiZaxis_size_get, _CdiObj.CdiZaxis_size_set)
    __swig_setmethods__["prec"] = _CdiObj.CdiZaxis_prec_set
    __swig_getmethods__["prec"] = _CdiObj.CdiZaxis_prec_get
    if _newclass:prec = _swig_property(_CdiObj.CdiZaxis_prec_get, _CdiObj.CdiZaxis_prec_set)
    __swig_setmethods__["plevels"] = _CdiObj.CdiZaxis_plevels_set
    __swig_getmethods__["plevels"] = _CdiObj.CdiZaxis_plevels_get
    if _newclass:plevels = _swig_property(_CdiObj.CdiZaxis_plevels_get, _CdiObj.CdiZaxis_plevels_set)
    __swig_setmethods__["plbounds"] = _CdiObj.CdiZaxis_plbounds_set
    __swig_getmethods__["plbounds"] = _CdiObj.CdiZaxis_plbounds_get
    if _newclass:plbounds = _swig_property(_CdiObj.CdiZaxis_plbounds_get, _CdiObj.CdiZaxis_plbounds_set)
    __swig_setmethods__["pubounds"] = _CdiObj.CdiZaxis_pubounds_set
    __swig_getmethods__["pubounds"] = _CdiObj.CdiZaxis_pubounds_get
    if _newclass:pubounds = _swig_property(_CdiObj.CdiZaxis_pubounds_get, _CdiObj.CdiZaxis_pubounds_set)
    __swig_setmethods__["pweights"] = _CdiObj.CdiZaxis_pweights_set
    __swig_getmethods__["pweights"] = _CdiObj.CdiZaxis_pweights_get
    if _newclass:pweights = _swig_property(_CdiObj.CdiZaxis_pweights_get, _CdiObj.CdiZaxis_pweights_set)
    __swig_setmethods__["levels"] = _CdiObj.CdiZaxis_levels_set
    __swig_getmethods__["levels"] = _CdiObj.CdiZaxis_levels_get
    if _newclass:levels = _swig_property(_CdiObj.CdiZaxis_levels_get, _CdiObj.CdiZaxis_levels_set)
    __swig_setmethods__["lbounds"] = _CdiObj.CdiZaxis_lbounds_set
    __swig_getmethods__["lbounds"] = _CdiObj.CdiZaxis_lbounds_get
    if _newclass:lbounds = _swig_property(_CdiObj.CdiZaxis_lbounds_get, _CdiObj.CdiZaxis_lbounds_set)
    __swig_setmethods__["ubounds"] = _CdiObj.CdiZaxis_ubounds_set
    __swig_getmethods__["ubounds"] = _CdiObj.CdiZaxis_ubounds_get
    if _newclass:ubounds = _swig_property(_CdiObj.CdiZaxis_ubounds_get, _CdiObj.CdiZaxis_ubounds_set)
    __swig_setmethods__["weights"] = _CdiObj.CdiZaxis_weights_set
    __swig_getmethods__["weights"] = _CdiObj.CdiZaxis_weights_get
    if _newclass:weights = _swig_property(_CdiObj.CdiZaxis_weights_get, _CdiObj.CdiZaxis_weights_set)
    __swig_setmethods__["name"] = _CdiObj.CdiZaxis_name_set
    __swig_getmethods__["name"] = _CdiObj.CdiZaxis_name_get
    if _newclass:name = _swig_property(_CdiObj.CdiZaxis_name_get, _CdiObj.CdiZaxis_name_set)
    __swig_setmethods__["longname"] = _CdiObj.CdiZaxis_longname_set
    __swig_getmethods__["longname"] = _CdiObj.CdiZaxis_longname_get
    if _newclass:longname = _swig_property(_CdiObj.CdiZaxis_longname_get, _CdiObj.CdiZaxis_longname_set)
    __swig_setmethods__["units"] = _CdiObj.CdiZaxis_units_set
    __swig_getmethods__["units"] = _CdiObj.CdiZaxis_units_get
    if _newclass:units = _swig_property(_CdiObj.CdiZaxis_units_get, _CdiObj.CdiZaxis_units_set)
CdiZaxis_swigregister = _CdiObj.CdiZaxis_swigregister
CdiZaxis_swigregister(CdiZaxis)

class CdiVariable(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, CdiVariable, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, CdiVariable, name)
    __repr__ = _swig_repr
    def __init__(self, *args): 
        this = _CdiObj.new_CdiVariable(*args)
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _CdiObj.delete_CdiVariable
    __del__ = lambda self : None;
    __swig_setmethods__["varID"] = _CdiObj.CdiVariable_varID_set
    __swig_getmethods__["varID"] = _CdiObj.CdiVariable_varID_get
    if _newclass:varID = _swig_property(_CdiObj.CdiVariable_varID_get, _CdiObj.CdiVariable_varID_set)
    __swig_setmethods__["zaxisID"] = _CdiObj.CdiVariable_zaxisID_set
    __swig_getmethods__["zaxisID"] = _CdiObj.CdiVariable_zaxisID_get
    if _newclass:zaxisID = _swig_property(_CdiObj.CdiVariable_zaxisID_get, _CdiObj.CdiVariable_zaxisID_set)
    __swig_setmethods__["gridID"] = _CdiObj.CdiVariable_gridID_set
    __swig_getmethods__["gridID"] = _CdiObj.CdiVariable_gridID_get
    if _newclass:gridID = _swig_property(_CdiObj.CdiVariable_gridID_get, _CdiObj.CdiVariable_gridID_set)
    __swig_setmethods__["taxisID"] = _CdiObj.CdiVariable_taxisID_set
    __swig_getmethods__["taxisID"] = _CdiObj.CdiVariable_taxisID_get
    if _newclass:taxisID = _swig_property(_CdiObj.CdiVariable_taxisID_get, _CdiObj.CdiVariable_taxisID_set)
    __swig_setmethods__["timeID"] = _CdiObj.CdiVariable_timeID_set
    __swig_getmethods__["timeID"] = _CdiObj.CdiVariable_timeID_get
    if _newclass:timeID = _swig_property(_CdiObj.CdiVariable_timeID_get, _CdiObj.CdiVariable_timeID_set)
    __swig_setmethods__["vlistID"] = _CdiObj.CdiVariable_vlistID_set
    __swig_getmethods__["vlistID"] = _CdiObj.CdiVariable_vlistID_get
    if _newclass:vlistID = _swig_property(_CdiObj.CdiVariable_vlistID_get, _CdiObj.CdiVariable_vlistID_set)
    __swig_setmethods__["size"] = _CdiObj.CdiVariable_size_set
    __swig_getmethods__["size"] = _CdiObj.CdiVariable_size_get
    if _newclass:size = _swig_property(_CdiObj.CdiVariable_size_get, _CdiObj.CdiVariable_size_set)
    __swig_setmethods__["code"] = _CdiObj.CdiVariable_code_set
    __swig_getmethods__["code"] = _CdiObj.CdiVariable_code_get
    if _newclass:code = _swig_property(_CdiObj.CdiVariable_code_get, _CdiObj.CdiVariable_code_set)
    __swig_setmethods__["datatype"] = _CdiObj.CdiVariable_datatype_set
    __swig_getmethods__["datatype"] = _CdiObj.CdiVariable_datatype_get
    if _newclass:datatype = _swig_property(_CdiObj.CdiVariable_datatype_get, _CdiObj.CdiVariable_datatype_set)
    __swig_setmethods__["streamID"] = _CdiObj.CdiVariable_streamID_set
    __swig_getmethods__["streamID"] = _CdiObj.CdiVariable_streamID_get
    if _newclass:streamID = _swig_property(_CdiObj.CdiVariable_streamID_get, _CdiObj.CdiVariable_streamID_set)
    __swig_setmethods__["name"] = _CdiObj.CdiVariable_name_set
    __swig_getmethods__["name"] = _CdiObj.CdiVariable_name_get
    if _newclass:name = _swig_property(_CdiObj.CdiVariable_name_get, _CdiObj.CdiVariable_name_set)
    __swig_setmethods__["longname"] = _CdiObj.CdiVariable_longname_set
    __swig_getmethods__["longname"] = _CdiObj.CdiVariable_longname_get
    if _newclass:longname = _swig_property(_CdiObj.CdiVariable_longname_get, _CdiObj.CdiVariable_longname_set)
    __swig_setmethods__["units"] = _CdiObj.CdiVariable_units_set
    __swig_getmethods__["units"] = _CdiObj.CdiVariable_units_get
    if _newclass:units = _swig_property(_CdiObj.CdiVariable_units_get, _CdiObj.CdiVariable_units_set)
    __swig_setmethods__["stdname"] = _CdiObj.CdiVariable_stdname_set
    __swig_getmethods__["stdname"] = _CdiObj.CdiVariable_stdname_get
    if _newclass:stdname = _swig_property(_CdiObj.CdiVariable_stdname_get, _CdiObj.CdiVariable_stdname_set)
    __swig_setmethods__["missval"] = _CdiObj.CdiVariable_missval_set
    __swig_getmethods__["missval"] = _CdiObj.CdiVariable_missval_get
    if _newclass:missval = _swig_property(_CdiObj.CdiVariable_missval_get, _CdiObj.CdiVariable_missval_set)
    __swig_setmethods__["values"] = _CdiObj.CdiVariable_values_set
    __swig_getmethods__["values"] = _CdiObj.CdiVariable_values_get
    if _newclass:values = _swig_property(_CdiObj.CdiVariable_values_get, _CdiObj.CdiVariable_values_set)
    __swig_setmethods__["valuesWithLevel"] = _CdiObj.CdiVariable_valuesWithLevel_set
    __swig_getmethods__["valuesWithLevel"] = _CdiObj.CdiVariable_valuesWithLevel_get
    if _newclass:valuesWithLevel = _swig_property(_CdiObj.CdiVariable_valuesWithLevel_get, _CdiObj.CdiVariable_valuesWithLevel_set)
    __swig_setmethods__["grid"] = _CdiObj.CdiVariable_grid_set
    __swig_getmethods__["grid"] = _CdiObj.CdiVariable_grid_get
    if _newclass:grid = _swig_property(_CdiObj.CdiVariable_grid_get, _CdiObj.CdiVariable_grid_set)
    __swig_setmethods__["zaxis"] = _CdiObj.CdiVariable_zaxis_set
    __swig_getmethods__["zaxis"] = _CdiObj.CdiVariable_zaxis_get
    if _newclass:zaxis = _swig_property(_CdiObj.CdiVariable_zaxis_get, _CdiObj.CdiVariable_zaxis_set)
    __swig_setmethods__["taxis"] = _CdiObj.CdiVariable_taxis_set
    __swig_getmethods__["taxis"] = _CdiObj.CdiVariable_taxis_get
    if _newclass:taxis = _swig_property(_CdiObj.CdiVariable_taxis_get, _CdiObj.CdiVariable_taxis_set)
    def sinfo(*args): return _CdiObj.CdiVariable_sinfo(*args)
    def getValues(*args): return _CdiObj.CdiVariable_getValues(*args)
    def getValuesWithLevel(*args): return _CdiObj.CdiVariable_getValuesWithLevel(*args)
    def getFValues(*args): return _CdiObj.CdiVariable_getFValues(*args)
    def getFValuesWithLevel(*args): return _CdiObj.CdiVariable_getFValuesWithLevel(*args)
    def getValuesAsPointer(*args): return _CdiObj.CdiVariable_getValuesAsPointer(*args)
    def getValuesWithLevelAsPointer(*args): return _CdiObj.CdiVariable_getValuesWithLevelAsPointer(*args)
CdiVariable_swigregister = _CdiObj.CdiVariable_swigregister
CdiVariable_swigregister(CdiVariable)

class Cdi(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Cdi, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Cdi, name)
    __repr__ = _swig_repr
    def __init__(self, *args): 
        this = _CdiObj.new_Cdi(*args)
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _CdiObj.delete_Cdi
    __del__ = lambda self : None;
    __swig_setmethods__["streamID"] = _CdiObj.Cdi_streamID_set
    __swig_getmethods__["streamID"] = _CdiObj.Cdi_streamID_get
    if _newclass:streamID = _swig_property(_CdiObj.Cdi_streamID_get, _CdiObj.Cdi_streamID_set)
    __swig_setmethods__["vlistID"] = _CdiObj.Cdi_vlistID_set
    __swig_getmethods__["vlistID"] = _CdiObj.Cdi_vlistID_get
    if _newclass:vlistID = _swig_property(_CdiObj.Cdi_vlistID_get, _CdiObj.Cdi_vlistID_set)
    __swig_setmethods__["nvars"] = _CdiObj.Cdi_nvars_set
    __swig_getmethods__["nvars"] = _CdiObj.Cdi_nvars_get
    if _newclass:nvars = _swig_property(_CdiObj.Cdi_nvars_get, _CdiObj.Cdi_nvars_set)
    __swig_setmethods__["nzaxes"] = _CdiObj.Cdi_nzaxes_set
    __swig_getmethods__["nzaxes"] = _CdiObj.Cdi_nzaxes_get
    if _newclass:nzaxes = _swig_property(_CdiObj.Cdi_nzaxes_get, _CdiObj.Cdi_nzaxes_set)
    __swig_setmethods__["ngrids"] = _CdiObj.Cdi_ngrids_set
    __swig_getmethods__["ngrids"] = _CdiObj.Cdi_ngrids_get
    if _newclass:ngrids = _swig_property(_CdiObj.Cdi_ngrids_get, _CdiObj.Cdi_ngrids_set)
    __swig_setmethods__["ntaxes"] = _CdiObj.Cdi_ntaxes_set
    __swig_getmethods__["ntaxes"] = _CdiObj.Cdi_ntaxes_get
    if _newclass:ntaxes = _swig_property(_CdiObj.Cdi_ntaxes_get, _CdiObj.Cdi_ntaxes_set)
    __swig_setmethods__["taxisID"] = _CdiObj.Cdi_taxisID_set
    __swig_getmethods__["taxisID"] = _CdiObj.Cdi_taxisID_get
    if _newclass:taxisID = _swig_property(_CdiObj.Cdi_taxisID_get, _CdiObj.Cdi_taxisID_set)
    __swig_setmethods__["varnames"] = _CdiObj.Cdi_varnames_set
    __swig_getmethods__["varnames"] = _CdiObj.Cdi_varnames_get
    if _newclass:varnames = _swig_property(_CdiObj.Cdi_varnames_get, _CdiObj.Cdi_varnames_set)
    __swig_setmethods__["codes"] = _CdiObj.Cdi_codes_set
    __swig_getmethods__["codes"] = _CdiObj.Cdi_codes_get
    if _newclass:codes = _swig_property(_CdiObj.Cdi_codes_get, _CdiObj.Cdi_codes_set)
    __swig_setmethods__["variables"] = _CdiObj.Cdi_variables_set
    __swig_getmethods__["variables"] = _CdiObj.Cdi_variables_get
    if _newclass:variables = _swig_property(_CdiObj.Cdi_variables_get, _CdiObj.Cdi_variables_set)
    __swig_setmethods__["var"] = _CdiObj.Cdi_var_set
    __swig_getmethods__["var"] = _CdiObj.Cdi_var_get
    if _newclass:var = _swig_property(_CdiObj.Cdi_var_get, _CdiObj.Cdi_var_set)
    __swig_setmethods__["varByCode"] = _CdiObj.Cdi_varByCode_set
    __swig_getmethods__["varByCode"] = _CdiObj.Cdi_varByCode_get
    if _newclass:varByCode = _swig_property(_CdiObj.Cdi_varByCode_get, _CdiObj.Cdi_varByCode_set)
    __swig_setmethods__["taxes"] = _CdiObj.Cdi_taxes_set
    __swig_getmethods__["taxes"] = _CdiObj.Cdi_taxes_get
    if _newclass:taxes = _swig_property(_CdiObj.Cdi_taxes_get, _CdiObj.Cdi_taxes_set)
    __swig_setmethods__["zaxes"] = _CdiObj.Cdi_zaxes_set
    __swig_getmethods__["zaxes"] = _CdiObj.Cdi_zaxes_get
    if _newclass:zaxes = _swig_property(_CdiObj.Cdi_zaxes_get, _CdiObj.Cdi_zaxes_set)
    __swig_setmethods__["grids"] = _CdiObj.Cdi_grids_set
    __swig_getmethods__["grids"] = _CdiObj.Cdi_grids_get
    if _newclass:grids = _swig_property(_CdiObj.Cdi_grids_get, _CdiObj.Cdi_grids_set)
    def griddes(*args): return _CdiObj.Cdi_griddes(*args)
Cdi_swigregister = _CdiObj.Cdi_swigregister
Cdi_swigregister(Cdi)






#!/usr/bin/env python
from distutils.core import setup, Extension
from setup import *

CdiLib_module = Extension('_CdiLib',
                  sources=['cdilib_wrap.c'],
                  extra_compile_args = INCFLAGS,
                  library_dirs = LDFLAGS,
                  extra_objects = ['../../src/cdilib.o'],
                  extra_link_args = LIBS,
                  )

setup (name = 'CdiLib',
       version = '0.1',
       author      = "Ralf Mueller",
       description = """pyhton bindings to CDI function library""",
       ext_modules = [CdiLib_module],
       py_modules = ["CdiLib"],
       )



#!/usr/bin/env python
from distutils.core import setup, Extension
from setup import *

cdiobj_module = Extension('_CdiObj',
                  sources=['cdiobj_wrap.cpp'],
                  extra_compile_args = INCFLAGS,
                  library_dirs = LDFLAGS,
                  extra_objects = ['../cdi.o'],
                  runtime_library_dirs = [os.environ['BUILDLIBDIR'],os.environ['LIBDIR']],
                  extra_link_args = LIBS,
                  libraries    = ['cdi','stdc++'],
                  language = 'c++',
                  )

setup (name = 'CdiObj',
       version = '0.1',
       author      = "Ralf Mueller",
       description = """pyhton bindings to CDI class library""",
       ext_modules = [cdiobj_module],
       py_modules = ["CdiObj"],
       )



import CdiLib
ifile = "../testdata/mulval.nc"
streamID = CdiLib.streamOpenRead(ifile)
vlistID  = CdiLib.streamInqVlist(streamID)
nvars    = CdiLib.vlistNvars(vlistID)
for i in range(0,nvars):
  print CdiLib.vlistInqVarCode(vlistID, i),

CdiLib.streamClose(streamID)



import os, numpy, getopt, sys
import CdiObj


def usage():
  print("usage: " + sys.argv[0] + " [-o outputFile] [-e experiementTag] [-v] inputFile")

def htmlSkel(experiment):
  return ['<html> <head> <title>ECHAM Experiment: '+ experiment +'</title></head>' +
  """<body>
<script type="text/javascript" src="http://code.jquery.com/jquery-1.4.2.min.js"></script> 
<script type="text/javascript" src="https://code.zmaw.de/files/cdo/html/tableFold.js"></script>""",
  '''</body>
    </html>
  ''']

def tableSkel():
  return ["<table id=\"detail_table\" class=\"detail\"> <!--       <col style=\"width: 40px;\"> <col style=\"width: 80px;\"> <col style=\"width: 80px;\"> <col style=\"width: 80px;\">-->" +
          "<thead align=\"left\"><tr align=\"right\"><th>Code</th><th>North</th><th>South</th><th colspan=\"1000\">Global</th></tr></thead>",
          '</table>']

def tableRow(code,northVal,southVal,globalVal):
  return ["<tr  align=\"right\" title=\"Click to expand/collapse\" style=\"cursor: pointer;\" class=\"parent\" id=\"row%d\" >" % code +
          "<td valign=\"top\">%d</td><td>%3.3f</td><td>%3.3f</td><td>%3.3f</td>" % (code,northVal, southVal, globalVal) +
          '</tr>' + 
          "<tr style=\"display: none;\" class=\"child-row%d\">" % code + 
          '<td></td><td colspan="3">', 
          '</td></tr></table>']

def generateSubTable(headers, rows):
  html = []

  if len(headers) > 0:
    html.append("<tr>")
  for header in headers:
    html.append("<th>" + header + "</th>")
  html.append("</tr>")

  if len(rows) > 0:
    for row in rows:
      html.append("<tr>")
      for cell in row:
        html.append("<td>%3.3f</td>" % cell)
  html.append("</tr>")

  if html:
    html  = ["<table>"] + html + ["</table>"]

  return "".join(html)  

if __name__ == '__main__':
  try:
    opts, args = getopt.getopt(sys.argv[1:], "ho:v", ["help", "output="])
  except getopt.GetoptError, err:
    #print help information and exit:
    print str(err) # will print something like "option -a not recognized"
    usage()
    sys.exit(2)

  output  = 'table.html'
  expName = '187'
  verbose = False
  for o, a in opts:
    if o == "-v":
      verbose = True
    elif o in ("-h", "--help"):
      usage()
      sys.exit()
    elif o in ("-o", "--output"):
      output = a
    elif o in ("-e", "--experiment"):
      expName = a
    else:
      assert False, "unhandled option"
  
  sourcefile = args[0]
  #TODO test if input file exists?
  if verbose == True:
    print 'Input:  ' + sourcefile
    print 'Output: ' + output
 
  cdoOperator = "zonavg"
  zonalfile   = cdoOperator + "-" + sourcefile
  cmd         = ' '.join(['cdo',cdoOperator, sourcefile, zonalfile])

  print cmd

  os.popen(cmd).read()

  cdi = CdiObj.Cdi(zonalfile)

  html = []
  htmlStart, htmlEnd = htmlSkel(expName)
  tableStart, tableEnd = tableSkel()

  html.append(htmlStart)
  html.append(tableStart)

  for code in cdi.codes:

      var = cdi.varByCode[code]
      var.getValues()
      vals = numpy.array(var.values)
      lats = numpy.array(var.grid.yvalues)
      northInd = numpy.where(lats >= 0)
      southInd = numpy.where(lats <  0)
      if verbose == True:
        print 'Global Mean:     ',vals.mean()
        print 'Global Max|Min:  ',vals.max(),'|',vals.min()
        print 'North  Mean:     ',vals[northInd].mean()
        print 'South  Mean:     ',vals[southInd].mean()
      
      codeTableStart, codeTableEnd = tableRow(code,vals[northInd].mean(), vals[southInd].mean(), vals.mean())
      
      html.append(codeTableStart)

      tdata = numpy.array([lats[northInd],vals[northInd],lats[southInd],vals[southInd]]).transpose().tolist()
      vtable  = generateSubTable(["latitude","values","latidute","values"],tdata)

      html.append(vtable)


  html.append(tableEnd)
  html.append(htmlEnd)

  f = open(output, 'w')
  f.write("".join(html))
  f.close
